# 0. MASTER 

# Title : Effective Tax Rate and Firm Size
# Authors: Pierre Bachas, Anne Brockmeyer, Roel Dom and Camille Semelet
# Data Sources: CIT admin data, WDI

rm(list=ls(all=TRUE))

# IMPORTANT: 
#   step 1: get the USERNAME, type "Sys.getenv()" within the R Console 
#   step 2: replace username in line 119
#   step 3: adapt the path. Need Github access
#   

#########################################################################.
# 0. PACKAGES

# define a list of required packages

packages <- c("tidyverse", "data.table", "countrycode", "wbstats", "collapse" ,
              "stargazer", "lazyeval",
              "fixest", "broom", "jtools", "ggformula", "huxtable", "ggrepel",
              "readxl", "DescTools", "RStata",
              "xtable", "ggbrace")
# loop through the list of packages and check if they are installed and loaded
for (p in packages) {
  if (!require(p, character.only = TRUE)) {
    install.packages(p)
    library(p, character.only = TRUE)
  }
}


#########################################################################.
# 1. USERS

# Github repository "Cross-country" has to be cloned 
# Depending on where the data is located, users and location can differ. 
# Each country can be run separately and metadata is saved each time
# to get the USERNAME, type "Sys.getenv()" within the R Console 


# --SERVER WBGMSTITX001:
upi <- Sys.getenv("USERNAME")

  if (Sys.getenv("COMPUTERNAME") == "WBGMSTITX001") {
    print(paste("Access to micro data"))
    ## Paths & objects 
    proc_data <- "D:/Crosscountrytax/replication/data/output/"  
    if (upi == "S532468") {
      gitHub <- "C:/WBG/rep-checks/Cross-Country/"
    } else {
      gitHub <- paste0("C:/Users/", upi, "/Cross-Country/")
    }
    country_name <- c("Mexico", "Senegal", "Albania", "Honduras", "Rwanda", "Dominican Republic", "Costa Rica",  "Guatemala", "Ecuador", "Jamaica") 
    country_code <- c("MEX", "SEN", "ALB", "HND", "RWA", "DOM", "CRI", "GTM", "ECU", "JAM")
    pre <- "wb_"
    # Select countries where we run the complete GMT analysis
    country_GMT <- c("HND", "CRI", "JAM")
    
   } else {
  
# --RUN OUTSIDE SERVER:
    
  if (Sys.getenv("USERNAME") == "wb551964") {
    upi <- "551964"
    
      print(paste("Access to micro data"))
  
      ## Paths & objects 
      proc_data <- paste0("C:/Users/wb", upi, "/Dropbox/Work/Data/Greek CIT")
      gitHub <- paste0("C:/Users/wb", upi, "/Documents/Cross-Country/")  
      #gitHub <- "C:\\Users\\semelet\\Cross-Country\\" ### GITHUB REPOSITORY LOCATED HERE   
      country_name <-c("Greece")   ### Country name
      country_code <- c("GRC")       ### Country iso code
      pre <- "s_"
      country_GMT <- c("GRC")
      
    
# --OUTSIDE COLLABORATORS:
    
 } else {

# --IFS team members
  if (Sys.getenv("USERNAME") == "vedanth_n") {
    print(paste("The user is Vedanth (IFS)"))
    ## Paths & objects
    proc_data <- "R:\\Data\\Ethiopian VAT and CIT\\2023_01_27_Archive\\Corporate tax work\\"
    gitHub <- "T:\\Cross-Country\\"
    country_name <-c("Ethiopia")
    country_code <- c("ETH")
    pre <- "ifs_"

  } else {

  if (Sys.getenv("USERNAME") == "ben_w") {
      print(paste("The user is Ben (IFS)"))
      ## Paths & objects
      proc_data <- "T:\\"
      gitHub <- "T:\\crosscountry_anne\\Cross-Country\\"
      country_name <-c("Ethiopia")
      country_code <- c("ETH")
      pre <- "ifs_"

  } else {

# --KYLEMCNABB, ODI
  if (Sys.getenv("USER") == "kylemcnabb"){
      print(paste("The user is Kyle (ODI)"))
      ## Paths & objects
      proc_data <- "//Users//kylemcnabb//Documents//Documents (MacBook Air)//NO NAME Backup December 2020//"
      gitHub <-  "//Users//kylemcnabb//Documents//GitHub//Cross-Country//"
      country_name <-c("Uganda")
      country_code <- c("UGA")
      pre <- "odi_"
  } else {

# --Adrienne Lees, ICTD
  if (Sys.getenv("USERNAME") == "Adi"){
        print(paste("The user is Adi (ICTD)"))
        ## Paths & objects
        proc_data <- "C:\\Users\\Phil\\OneDrive - University of Sussex\\ICTD\\Data\\"   
        gitHub <- "C:\\Users\\Phil\\OneDrive - University of Sussex\\ICTD\\Cross-Country\\" 
        country_name <-c("Eswatini")
        country_code <- c("ESW")
        pre <- "ictd_"
  } else {
    
    # --COLOMBIA 
    if (Sys.getenv("USERNAME") == "XXX "){ ## CHANGE HERE
      print(paste("The user is XXX (XXXX)")) ## CHANGE HERE
      ## Paths & objects
      proc_data <- "XXXX" ## CHANGE HERE
      gitHub <- "XXXX"   ### GITHUB REPOSITORY LOCATED HERE  
      country_name <-c("Colombia")
      country_code <- c("COL")
      pre <- "col_"
    } else {
      
      # -- Santiago local 
      if (Sys.getenv("USERNAME") == "Santi"){ ## CHANGE HERE
        print(paste("The user is Santiago (local)")) ## CHANGE HERE
        country_name <- c("Mexico", "Senegal", "Albania", "Honduras", "Rwanda", "Dominican Republic", "Costa Rica",  "Guatemala", "Ecuador", "Jamaica")  
        country_code <- c("MEX", "SEN", "ALB", "HND", "RWA", "DOM", "CRI", "GTM", "ECU", "JAM")
        gitHub <- "D:/Users/Santi/Documents/GitHub/Cross-Country/"   ### GITHUB REPOSITORY LOCATED HERE  
      } 
      
    }}}}}}} 


#########################################################################.
# 3. PATHS

project <- "../"

## On gitHub
code <- paste0(gitHub, project, "/codes/")    ## dofiles
aux_source <- paste0(gitHub, project, "/codes/Auxillary codes/")
regressions <-  paste0(gitHub, project, "/output/regressions/")
metadata <-  paste0(gitHub, project, "/output/metadata/")
output <-  paste0(gitHub, project, "/output/")


#########################################################################.
# 1. PREPARE RAW CIT DATA

if (Sys.getenv("COMPUTERNAME") == "WBGMSTITX001") {
  
  options("RStata.StataPath" = "\"C:\\Program Files\\Stata16\\StataMP-64\"")
  options("RStata.StataVersion" = 16)
  setwd(code)
  stata("0_master_cleaning.do")
  
}

#########################################################################

# 4. LOAD CIT DATA

data_raw <- list() # Creates an empty list. This is where we store the .dta files
files <- paste0(country_code, "_withvars.csv", sep = "") # Names of the Files to be read. 

for (i in 1: length(files)){
  if (Sys.getenv("COMPUTERNAME") == "WBGMSTITX001") {
    directory <- paste0(proc_data, country_name[i], sep = "") 
  } else { 
    directory <- proc_data
  }
  setwd(directory)
  df  <- fread(files[i], integer64 = "numeric") 
  
  ## fread read some columns as integer64 instead of numeric. 
  ## The conversion above does not work when column is being bumped to integer64
  ## (i.e. out of sample type bump occuring) 
  ## a workaround is as follows:
  
  coln.int64 <- names(which(sapply(df, bit64::is.integer64)))
  if (length(coln.int64) > 0L)
    df[ , c(coln.int64) := lapply(.SD, as.numeric), .SDcols = coln.int64]
  data_raw[[i]] <- df %>% as.data.frame()
  print(country_name[i])
} #end loop

print("Data loaded")


#########################################################################.
# 4. READ & PREPARE DATA

# Take raw data add WDI variables create the main dataset:
#   cross-sectional (last year) (list df.sample)
#   panel data (list data)
#   STR is 
#   Restrictions are as follows: 
#       - turnover > 1
#       - df.sample is the latest year & != 2020
# 
#########################################################################.



#########################################################################.
# 7. GMT ANALYSIS 
#
prepare_data <- "GMT_cleaning"
#
setwd(code)
source("1_prepare_data.R")
#
setwd(code)
source("2.1_GMT_simulation.R")
#
setwd(code)
source("2.2_Minimum_Tax_Top1.R")
#
setwd(code)
source("2.3_Minimum_Tax_Top1_output.R")

# 
# options("RStata.StataPath" = "C:/Program Files/Stata17/StataMP-64")
# options("RStata.StataVersion" = 17)
# setwd(code)
# file.create("RStata.log")
# stata("2_4_GMT_output")

options("RStata.StataPath" = "\"C:\\Program Files\\Stata16\\StataMP-64\"")
options("RStata.StataVersion" = 16)
setwd(code)
stata("2_4_GMT_output.do")

### Clean environment
rm(list = ls(all = TRUE)[sapply(mget(ls(all = TRUE)), class) != "character" &
                           !ls(all = TRUE) %in% 
                           c("data_raw", "data.cross", "data.panel")])

#########################################################################.
# 5. ETR ANALYSIS 

prepare_data <- "ETR_cleaning"
#
setwd(code)
source("1_prepare_data.R")
#
setwd(code)
source("2.1_descriptive_ETR.R")
#
setwd(code)
source("2.2_regression_ETR.R")
#
setwd(code)
source("2.3_output_ETR.R")


#########################################################################.
# 6. Figure A2 
#library(RStata)

#options("RStata.StataPath" = "\"C:\\Program Files\\Stata16\\StataMP-64\"")
#options("RStata.StataVersion" = 16)
setwd(code)
stata("Code_FA2.do")   ## dofiles


#########################################################################.
# 9. Appendix Table A9

setwd(code)
source("Code_TA9.R")

#########################################################################.
# 10. Orbis tables

setwd(code)
source("Orbis_Main.R")