/* ==============================================================================
Project: 	   	Effective Tax Rates, Firm Size, and the Global Minimum Tax
				Master do-file for data creation

Authors:		Pierre Bachas
				Anne Brockmeyer
				Roel Dom
				Camille Semelet
-------------------------------------------------------------------------------
Creation Date:          November 28th, 2024  
Last update:          	December 4th, 2024         
=============================================================================== */

drop _all
clear all
set more off
set varabbrev on

/* 
Packages used

ssc install egenmore
ssc install gtools
ssc install wid
ssc install unique
ssc install rscript
*/

/* ------------------------------------------------------------------------------
                                  0: Set locals and Paths
------------------------------------------------------------------------------- */

local user="`c(username)'"

global data "D:/Crosscountrytax/replication/data"

if "`user'" == "S532468" {
	global code "C:/WBG/rep-checks/Cross-Country/ETR/Replication Package/codes"
}
else {
	global code "C:/Users/`user'/Cross-Country/ETR/Replication Package/codes"
}

sysdir set PLUS "${code}/ado"

/*==============================================================================
							1: Data Creation
==============================================================================*/

/* Measure time */
scalar t1 = c(current_time)
local time1=t1

include "$code/cleaning/CIT_ALB"							// Albania dataset
include "$code/cleaning/CIT_CRI"							// Costa Rica dataset
include "$code/cleaning/CIT_DOM"							// Dominican Republic dataset
include "$code/cleaning/CIT_ECU"							// Ecuador dataset
include "$code/cleaning/CIT_GTM"							// Guatemala dataset
include "$code/cleaning/CIT_HND"							// Honduras dataset
include "$code/cleaning/CIT_JAM"							// Jamaica dataset
include "$code/cleaning/CIT_MEX"							// Mexico dataset
include "$code/cleaning/CIT_RWA"							// Rwanda dataset
include "$code/cleaning/CIT_SEN"							// Senegal dataset

/* These codes cannot be executed on the server as the input data is stored 
elsewhere for confidentiality reasons.

include "$code/cleaning/CIT_COL"							// Colombia dataset
include "$code/cleaning/CIT_ETH"							// Ethiopia dataset
rscript "$code/cleaning/CIT_GRC.R"							// Greece dataset
include "$code/cleaning/CIT_SWZ"							// Eswatini dataset
include "$code/cleaning/CIT_UGA"							// Uganda dataset
include "$code/cleaning/CIT_ZAF"							// South Africa dataset

*/

/* Erase temporary files */
foreach c in "Albania" "Costa Rica" "Dominican Republic" "Ecuador" "Guatemala" "Honduras" "Jamaica" "Mexico" "Rwanda" "Senegal" {
	
	cd "D:/Crosscountrytax/replication/data/temp/`c'"  
	local files1 : dir "D:/Crosscountrytax/replication/data/temp/`c'"  files "*.dta"
	local files2 : dir "D:/Crosscountrytax/replication/data/temp/`c'"  files "*.txt"
	local files3 : dir "D:/Crosscountrytax/replication/data/temp/`c'"  files "*.csv"


		foreach f of local files1 {  
			erase `f'  
		} 
		
		foreach f of local files2 {  
			erase `f'  
		}  
		
		foreach f of local files3 {  
			erase `f'  
		}  
}

/* Measure time */
scalar t2 = c(current_time)
local time2=t2

/* Display time */
di "`time1'"
di "`time2'"