# Bind datasets - Only needed for some countries
bind_data <- function(country){
  
  pattern <- "Export_.*_bvd_"
  folder <- paste0(raw_data_path, country)
  corresp_files <- list.files(folder, pattern = pattern, full.names = TRUE)
  
  df <- data.frame()
  for (i in corresp_files){
    
    col_types <- c(rep("text", 4), rep("numeric", 2), rep("text", 12))
    aux <- readxl::read_excel(i, sheet = 2, skip = 1, 
                              col_types = col_types) %>% select(-1)
    df <- bind_rows(df, aux)
    
  }
  return(df)
}

coutries_bind <- c("Albania", "Colombia","Greece", "Mexico", "South Africa")
iso_bind <- c("ALB", "COL", "GRC", "MEX", "ZAF")

for (j in 1:length(coutries_bind)) {
  
  df <- bind_data(coutries_bind[j])
  fwrite(df, paste0(raw_data_path, coutries_bind[j], "/Export_", iso_bind[j], "_bvd.csv"))
}


merge_data <- function(country, iso){
  
  folder_data <- paste0(raw_data_path, country, "/")
  
  # Step 2 - Data cleaning and manipulation ----
  if (iso %in% iso_bind){
    data <- fread(paste0(folder_data, paste0("Export_", iso, "_bvd.csv")))
  } else {
    data <- readxl::read_excel(paste0(folder_data, paste0("Export_", iso, "_bvd.xlsx")), 
                               sheet = 2, skip = 1) %>% select(-1) }
  
  #Step 3 - Create the grouping variable
  
  #Lets keep only the main shareholder 
  #fortunally orbis order the shareholders by % so we can just keep the first one)
  
  data$SH_BVD_ID_NUMBER <- sub("\n.*", "", data$SH_BVD_ID_NUMBER)
  
  data$SH_COUNTRY_ISO_CODE <- data$SH_COUNTRY_ISO_CODE %>%
    substr(1, 2)
  
  data$group <- ifelse(is.na(data$GUO_BVD_ID_NUMBER),
                       data$SH_BVD_ID_NUMBER,
                       data$GUO_BVD_ID_NUMBER)
  
  
  data$GUO_COUNTRY_ISO_CODE <- ifelse(is.na(data$GUO_COUNTRY_ISO_CODE),
                                      data$SH_COUNTRY_ISO_CODE,
                                      data$GUO_COUNTRY_ISO_CODE)
  
  data$`GUO - Name` <- ifelse(is.na(data$GUO_NAME),
                              data$SH_NAME,
                              data$GUO_NAME)
  
  return(data)
  
}


coutries <- c("Albania",  "Colombia", "Costa Rica", "Dominican Republic",
              "Ecuador",  "Eswatini", "Ethiopia", "Greece", "Guatemala", "Honduras",
              "Jamaica", "Mexico", "Rwanda", "Senegal", "South Africa", "Uganda")

iso <- c("ALB", "COL", "CRI", "DOM", "ECU", "SWZ", "ETH", "GRC", "GTM", "HND", "JAM",
         "MEX", "RWA", "SEN",  "ZAF", "UGA")


for (i in 1:length(coutries)) {
  
  df <- merge_data(coutries[i], iso[i])
  print(str(df$group))
  
  fwrite(df, paste0(int_path, iso[i], "_Subs.csv"))
}


