# Open the datasets and merge
years <- c(2015:2018)

join_MNE_subs <- function(data_name){
  
  data_subs <- fread(data_name, colClasses = c(group = "character"))
  
  # Convert the columns to character
  data_subs <- data_subs %>%
    mutate_at(c("group", "BVD_ID_NUMBER", "GUO_BVD_ID_NUMBER",
                "SH_BVD_ID_NUMBER"), as.character)
  
  
  
  data <- left_join(data_subs, data_MNE, by = c("group" = "GUO_BVD_ID_NUMBER"))
  
  data$filter_scope <- ifelse(is.na(data$n_total) == 0, 1, 0)
  
  # replace guo by shareholder if missing
  
  data <- data %>% mutate(GUO_BVD_ID_NUMBER = 
                            if_else(is.na(GUO_BVD_ID_NUMBER) == 1,
                                    SH_BVD_ID_NUMBER,
                                    if_else(GUO_BVD_ID_NUMBER == "",
                                            SH_BVD_ID_NUMBER,
                                            GUO_BVD_ID_NUMBER)),
                          `GUO_NAME` = 
                            if_else(is.na(GUO_NAME) == 1,
                                    SH_NAME,
                                    if_else(GUO_NAME == "",
                                            SH_NAME,
                                            GUO_NAME)))
  
  
  data <- data %>% select(NAME,
                          GUO_BVD_ID_NUMBER,
                          BVD_ID_NUMBER,
                          GUO_NAME,
                          GUO_BVD_ID_NUMBER,
                          GUO_COUNTRY_ISO_CODE,
                          n_total,
                          ORBISID,
                          VAT_NUMBER,
                          TIN,
                          LEI) %>% 
    relocate(BVD_ID_NUMBER, NAME, GUO_BVD_ID_NUMBER, GUO_NAME) %>%
    arrange(desc(GUO_BVD_ID_NUMBER))
  
  data <- data %>% filter(is.na(data$n_total) == 0)
  
  return(data)
}

# Function to filter columns
filter_columns <- function(df, threshold = 0.10) {
  
  # Calculate column-wise mean of non-NA values
  non_na_means <- colMeans(!is.na(df))
  
  # Identify columns where at least 5% is different than NA
  selected_columns <- names(non_na_means[non_na_means >= threshold])
  
  # Subset the original data frame
  df_filtered <- df %>% select(all_of(selected_columns))
  
  return(df_filtered)
}

coutries <- c("Albania",  "Colombia", "Costa Rica", "Dominican Republic",
              "Ecuador",  "Eswatini", "Ethiopia", "Greece", "Guatemala", "Honduras",
              "Jamaica", "Mexico", "Rwanda", "Senegal", "South Africa", "Uganda")

iso <- c("ALB", "COL", "CRI", "DOM", "ECU", "SWZ", "ETH", "GRC", "GTM", "HND", "JAM",
         "MEX", "RWA", "SEN",  "ZAF", "UGA")

for (seq in c("_t500", "")){
  
for (i in 1:length(coutries)) {
  
  MNE_path <- paste0(int_path, "MNEs_", years[1], "_", years[4], seq, ".csv")
  
  data_MNE <- fread(MNE_path, colClasses = c(`GUO_BVD_ID_NUMBER` = "character")) %>%
    select("GUO_BVD_ID_NUMBER", "n_total")
  
  path <- paste0(int_path, iso[i], "_Subs.csv")
  df <- join_MNE_subs(path)
  df <- filter_columns(df, threshold = 0.10)

  fwrite(df, paste0(final_path, iso[i], "_Subs", seq, "_Scope_GUO.csv"))
}
}


