# Part 1 - Lets first open and clean data ####

# Total count of firms
data_total <- 
  read_excel(paste0(raw_data_path, "General Extractions/Count_Turnover.xlsx"), skip = 4) %>%
  slice(seq(2, n()))

# Rename columns
colnames(data_total) <- c("Country", "Non_Zero", "Zero", "na", "Total")

# Clening
data_total <- data_total %>%
  mutate(Non_Zero = as.numeric(Non_Zero),
         total_use = Non_Zero + Zero) %>%
  select(Country, "Total_firms" = Total, "Total_t_Firms" = total_use)


# Total count of subsidiaries
data_subs <- 
  read_excel(paste0(raw_data_path, "General Extractions/Subsidiaries_Count.xlsx"), skip = 4) %>%
  slice(seq(2, n()))

# Rename columns
colnames(data_subs) <- c("Country", "Non_Zero", "Zero", "na", "Total")

# Clening
data_subs <- data_subs %>%
  mutate(Non_Zero = as.numeric(Non_Zero),
         total_use = Non_Zero + Zero) %>%
  select(Country, "Total_subsidiaries" = Total, "Total_t_subsidiaries" = total_use)

# Join the columns
data_joined <- left_join(data_total, data_subs, by = "Country")

# Organize the ISO column
data_joined <- data_joined %>%
  mutate(iso = substr(Country, nchar(Country) - 2, nchar(Country) - 1))

# List countries
country_list = c("AL", "CO", "CR", "DO", "EC", "ET", "GR", "GT", "HN", "JM",
                 "MX", "RW", "SN", "SZ", "UG", "ZA")

# Keep selected countries
data_joined <- data_joined %>%
  filter(iso %in% country_list)

# Convert NAs to zero
data_joined <- data_joined %>%
  mutate(across(everything(), ~ replace_na(., 0)))

# Get share
data_joined <- data_joined %>%
  mutate(share_subs = round(100*(Total_t_subsidiaries/Total_subsidiaries ), 1),
         share_tot = round(100*(Total_t_Firms/Total_firms), 1))

# Part 2 - Editorial changes for final doc ----

# Clean the Country column
data_joined <- data_joined %>%
  mutate(Country = 
           stringr::str_remove(Country, " \\(.*\\)"))

#Organize Table
data_joined <- data_joined %>%
  select(Country, Total_t_subsidiaries, Total_subsidiaries,
         Total_t_Firms, Total_firms, share_subs, share_tot)

data_joined <- data_joined %>%
  mutate(
    Total_t_subsidiaries = as.integer(Total_t_subsidiaries),  
    Total_subsidiaries = as.integer(Total_subsidiaries),
    Total_t_Firms = as.integer(Total_t_Firms),
    Total_firms = as.integer(Total_firms))

# Rename columns
names <- c("Country", "Number of Subsidiaries with Turnover data",
           "Number os Subsidiaries", "Number of Firms with Turnover data",
           "Number of Firms", "Share of Subsidiaries with Turnover data", 
           "Share of Firms with Turnover data")

colnames(data_joined) <- names

# Re order
data_joined <- data_joined %>%
  arrange(Country)

# Save csv output
fwrite(data_joined, paste0(output_path, "TA12_Count_Turnover_Present.csv"))

# Convert the data frame to a LaTeX table
latex_table <- xtable(data_joined)

# Save the LaTeX table to a file
print(latex_table, file = paste0(output_path, "TA12_Count_Turnover_Present.tex"), 
      type = "latex", include.rownames = FALSE,
      digits = c(0, 0, 0, 0, 2, 2))
