rm(list=ls(all=TRUE)[sapply(mget(ls(all=TRUE)), class) != "character"])

print("Begin Output")

#######################| 1. LOAD AND MERGE METADATA |################################ 


setwd(metadata)
list.name <- c("df.ETR.descr", "df.ETR.avg.table", "df.ETR.size.p")

## Call source merge file
source(paste0(code, "Auxillary codes/merge_metadata_ETR.R"))

### Table Appendix A9 ###

# IMPORTANT NOTE. Run first all GMT codes, then run this table. 
# Part of the data used in this table comes from Code_GMT_Figures.DO do file and
# 3_GMT_top1pct_figure_new.R. 

ta9.1 <- df.ETR.descr %>% 
  select(country_name, country, year, count_scope, count_sez, count_sez_orbis) %>%
  rename( "Year" = year,
          "N_Scope" = count_scope,
          "N_SEZ" = count_sez,
          "N_SEZ_Orbis" = count_sez_orbis)

df_avg <- df.ETR.size.p %>% gather(Measure, value, "ETR_drop_avg":"ETR_keep_avg")  

ta9.2 <- df_avg %>% filter(ETR_denominator == "net_profit" & Measure == "ETR_keep_avg") %>%  
  select(country, n_keep, n_drop, n_keep_sez, n_liable_cbcr, n_etr_below15, n_etr_below15_1, n_etr_below15_2, n_foreign, n_drop, ETR_keep_avg_sez, ETR_drop_avg_sez, percentile_99.9) %>% 
  mutate(percentile_99.9 = if_else(percentile_99.9 >= 99, 99, percentile_99.9)) %>%
  group_by(country, percentile_99.9) %>% 
  summarize(n_keep = sum(n_keep, na.rm = T),
            n_etr_below15 = sum(n_etr_below15, na.rm = T),
            n_etr_below15_1 = sum(n_etr_below15_1, na.rm = T),
            n_etr_below15_2 = sum(n_etr_below15_2, na.rm = T),
            n_drop = sum(n_drop, na.rm = T),
            n_keep_sez = sum(n_keep_sez, na.rm = T),
            n_foreign = sum(n_foreign, na.rm = T),
            n_liable_cbcr = sum(n_liable_cbcr, na.rm = T),
            ETR_keep_avg_sez= mean(ETR_keep_avg_sez, na.rm = T),
            ETR_drop_avg_sez= mean(ETR_drop_avg_sez, na.rm = T)) %>% ungroup()

ta9.2 <- ta9.2 %>% select(country, n_keep, n_drop, n_etr_below15, n_liable_cbcr, n_etr_below15_1, n_etr_below15_2, n_foreign, ETR_keep_avg_sez, ETR_drop_avg_sez, percentile_99.9, n_keep_sez) %>%
  filter(percentile_99.9 == "99") %>%
  rename( "Percentiles" = percentile_99.9,
          "N_SEZ_T1" = n_keep_sez,
          "N_ETR_15" = n_etr_below15,
          "N_ETR_15_1" = n_etr_below15_1,
          "N_ETR_15_2" = n_etr_below15_2,
          "N_For_T1" = n_foreign,
          "N_Liable_T1" = n_liable_cbcr,
          "N_Firms_T1" = n_keep,
          "N_Firms_Prof_T1" = n_drop,
          "ETR_sez_all_T1" = ETR_keep_avg_sez,
          "ETR_sez_prof_T1" = ETR_drop_avg_sez) %>% 
  mutate(ETR_sez_all_T1 = if_else(country=="CRI" | country=="HND", ETR_sez_all_T1, NA_real_)) %>%
  mutate(ETR_sez_prof_T1 = if_else(country=="CRI" | country=="HND", ETR_sez_prof_T1, NA_real_)) %>%
  mutate(sh_n_foreign = N_For_T1/N_Firms_T1*100) %>%
  rename( "Sh_For_T1" = sh_n_foreign) %>%
  select(-Percentiles)

ta9.3 <- df_avg %>% filter(ETR_denominator == "net_profit" & Measure == "ETR_keep_avg") %>%  
  select(country, n_keep_sez, percentile_99.9) %>%
  filter(percentile_99.9 <= "50") %>%
  group_by(country) %>% 
  summarize(n_keep_sez = sum(n_keep_sez, na.rm = T)) %>%
  rename( "N_SEZ_B50" = n_keep_sez)

ta9.4 <- df.ETR.avg.table %>% filter(`treatment neg`=="Keep (SEZ)" | `treatment neg`=="Drop (SEZ)") %>% 
  select(country, net_profit, `treatment neg`) %>%
  pivot_wider(names_from = "treatment neg", values_from = net_profit) %>% 
  rename(ETR_sez_all = "Keep (SEZ)", ETR_sez_prof = "Drop (SEZ)") %>% 
  mutate_if(is.factor, as.character)

ta9.5 <- df_avg %>% filter(ETR_denominator == "net_profit" & Measure == "ETR_keep_avg") %>%  
  select(country, n_scope, percentile_99.9) %>% 
  mutate(percentile_99.9 = if_else(percentile_99.9 >= 99, 99, percentile_99.9)) %>%
  filter(percentile_99.9 >= "99") %>%
  group_by(country) %>% 
  summarize(n_scope = sum(n_scope, na.rm = T)) %>% ungroup() %>%
  rename( "N_Scope_T1" = n_scope)


ta9 <- left_join(ta9.1, ta9.2, by = c("country"))
ta9 <- left_join(ta9, ta9.3, by = c("country")) 
ta9 <- left_join(ta9, ta9.4, by = c("country")) 
ta9 <- left_join(ta9, ta9.5, by = c("country")) 

ta9 <- ta9 %>% arrange(country_name) %>% 
  mutate_if(is.numeric, round, digits = 2) %>% 
  mutate(ETR_SEZ_All_Prof = paste0(ETR_sez_all, " ", "(", ETR_sez_prof, ")")) %>%
  mutate(ETR_SEZ_All_Prof_T1 = paste0(ETR_sez_all_T1 , " ", "(", ETR_sez_prof_T1, ")")) %>%
  mutate(N_All_Prof_T1 = paste0(N_Firms_T1 , " ", "(", N_Firms_Prof_T1, ")")) %>%
  mutate(Sh_Scope_T1 = N_Scope_T1/N_Scope*100) %>%
  select(-ETR_sez_all, -ETR_sez_prof, -ETR_sez_all_T1, -ETR_sez_prof_T1, -N_Scope, -N_Firms_T1, -N_Firms_Prof_T1, ETR_SEZ_All_Prof_T1) %>%
  relocate(country_name, Year, N_All_Prof_T1, N_ETR_15, Sh_For_T1, Sh_Scope_T1, N_SEZ, N_SEZ_T1, N_SEZ_B50, ETR_SEZ_All_Prof) %>% 
  mutate_if(is.numeric, round, digits = 2)


data_entities <- read_excel(paste0(output, "GMT/Entities_Taxed_TA9.xlsx")) %>%
  select(n_e_cbcr, country)

ta9 <- left_join(ta9, data_entities, by = c("country"))  %>%
  mutate(N_Ent_Topup=n_e_cbcr) 

c2 <- read.csv(paste0(output, "GMT/F5_Data_Below15.csv"))

ta9 <- left_join(ta9, c2, by = c("country"))  %>%
  mutate(N_ETR_15=n_below15)

ta9 <- ta9 %>% mutate(N_Ent_Topup = ifelse(is.na(N_Ent_Topup), 0, N_Ent_Topup)) %>%
  mutate(N_Liable_T1 = as.numeric(N_Liable_T1)) %>%
  mutate(N_Ent_Topup = as.numeric(N_Ent_Topup)) %>%
  mutate(Sh_Liable_T1 = N_Liable_T1/N_Ent_Topup*100)

ta9 <- ta9 %>% 
  mutate_all(as.character) %>%
  mutate(N_SEZ = if_else(country=="ALB" | country=="COL" | country=="ESW" | country=="ETH" | country=="GRC" | country=="UGA", "NA", N_SEZ)) %>%
  mutate(N_SEZ_B50 = if_else(country=="ALB" | country=="COL" | country=="ESW" | country=="ETH" | country=="GRC" | country=="UGA", "NA", N_SEZ_B50)) %>%
  mutate(N_SEZ_T1 = if_else(country=="ALB" | country=="COL" | country=="ESW" | country=="ETH" | country=="GRC" | country=="UGA", "NA", N_SEZ_T1)) %>%
  mutate(N_SEZ_Orbis = if_else(country=="SEN" | country=="RWA" | country=="DOM" | country=="ECU" | country=="GTM" | country=="ALB" | country=="COL" | country=="ESW" | country=="ETH" | country=="GRC" | country=="UGA" | country=="MEX", "NA", N_SEZ_Orbis)) %>%
  mutate(Sh_Scope_T1 = if_else(country=="SEN" | country=="RWA" | country=="DOM" | country=="ECU" | country=="GTM" | country=="ALB" | country=="COL" | country=="ESW" | country=="ETH" | country=="UGA" | country=="MEX", "NA", Sh_Scope_T1)) %>%
  mutate(Sh_Liable_T1 = if_else(country=="SEN" | country=="RWA" | country=="DOM" | country=="ECU" | country=="GTM" | country=="ALB" | country=="COL" | country=="ESW" | country=="ETH" | country=="UGA" | country=="MEX" | country=="ZAF", "NA", Sh_Liable_T1)) %>%
  mutate(Sh_For_T1 = if_else(country=="SEN" | country=="RWA" | country=="DOM" | country=="ECU" | country=="GTM" | country=="ALB" | country=="COL" | country=="ESW" | country=="ETH" | country=="MEX" | country=="UGA", "NA", Sh_For_T1)) %>%
  mutate(ETR_SEZ_All_Prof = if_else(country=="ALB" | country=="COL" | country=="ESW" | country=="ETH" | country=="GRC" | country=="UGA", "NA", ETR_SEZ_All_Prof)) %>%
  mutate(ETR_SEZ_All_Prof_T1 = if_else(country=="ALB" | country=="COL" | country=="ESW" | country=="ETH" | country=="GRC" | country=="UGA", "NA", ETR_SEZ_All_Prof_T1)) %>%
  mutate(ETR_SEZ_All_Prof = if_else(country=="MEX", "-", ETR_SEZ_All_Prof)) %>%
  mutate(N_Ent_Topup = if_else(country=="SEN" | country=="RWA" | country=="DOM" | country=="ECU" | country=="GTM" | country=="ALB" | country=="COL" | country=="ESW" | country=="ETH" | country=="MEX" | country=="UGA", "NA", N_Ent_Topup)) %>%
  mutate(ETR_SEZ_All_Prof_T1 = if_else(country=="DOM" | country=="ECU" | country=="GTM" | country=="JAM" | country=="MEX" | country=="RWA" | country=="SEN" | country=="ZAF", "-", ETR_SEZ_All_Prof_T1))

ta9 <- ta9 %>%  select(-Sh_Scope_T1, -N_Liable_T1, -country, -N_For_T1, -N_SEZ_Orbis, -N_Scope_T1, -ETR_SEZ_All_Prof_T1, -n_e_cbcr, -N_ETR_15_1, -N_ETR_15_2, -X, -n_below15) %>%
  relocate(country_name, Year, N_All_Prof_T1, N_ETR_15, Sh_For_T1, N_Ent_Topup, Sh_Liable_T1, N_SEZ, N_SEZ_T1, N_SEZ_B50, ETR_SEZ_All_Prof) %>%
  mutate(country_name = if_else(country_name=="Dominican Republic", "Dom. Rep.", country_name)) %>%
  mutate(country_name = if_else(country_name=="South Africa", "S. Africa", country_name))

setwd(paste0(output, "/tables"))

stargazer(ta9, rownames = FALSE, summary = FALSE,  out = "TA9_Top1_SEZ.tex", digits = 1)
latex_code <- readLines("TA9_Top1_SEZ.tex")
latex_code <- latex_code[!grepl("\\\\begin\\{table\\}|\\\\end\\{table\\}|\\\\caption\\{\\}|\\\\label\\{\\}", latex_code)]
writeLines(latex_code, "TA9_Top1_SEZ.tex")