*===============================================================================
* File name: 		AT01_AT02_JAM.do
* 
* Description:		This do-file creates the dataset JAM_withvars.csv. 
*
* Input:  					
*					$data/input/Jamaica/AT01_2018.xlsx
*					$data/input/Jamaica/AT02_2018.xlsx 
*					$data/input/Jamaica/OECD_Req_AT01_2016-2017.xlsx 
*					$data/input/Jamaica/OECD_Req_AT02_2016-2017.xlsx 
*
* Output:
*					$data/input/Jamaica/AT01_AT02_Assets_16_18.dta
*===============================================================================

cls
capture restore
set more off
cap log close
clear all
 
/* ------------------------ */
/* IMPORT & CLEAN 2018 DATA */
/* ------------------------ */

/* ---------------- */
/* Import AT01 data */
/* ---------------- */

/* Load data */
import excel using "$data/input/Jamaica/AT01_2018.xlsx", clear sh("AT01_2018") first

/* Check data */
duplicates report
duplicates report ANON_ID
bys ANON_ID: gen N=_N
order N, a(ANON_ID)
sort N ANON_ID
duplicates drop 

/* Create variables */
gen year=2018
gen foreign_ownership=(OverseasCompany==1)
gen tangible_assets_at=TotalFixedAsset
gen form="AT01"

/* Get mean share of fixed assets */
gen sh_fixed=TotalFixedAsset/DeterminedTaxable

/* Save data */
save "$data/temp/Jamaica/AT01.dta", replace

tempfile tempAT01
save `tempAT01', replace

/* ---------------- */
/* Import AT02 data */
/* ---------------- */

/* Load data */
import excel using "$data/input/Jamaica/AT02_2018.xlsx", clear sh("AT02_2018") first

/* Check data */
duplicates report

/* Create variables */
gen year=2018
gen foreign_ownership=(OverseasCompany==1)
gen tangible_assets_at=FixedAsset
gen form="AT02"

/* Get mean share of fixed assets */
gen sh_fixed=FixedAsset/AggregateAssets

/* Save data */
save "$data/temp/Jamaica/AT02.dta", replace

tempfile tempAT02
save `tempAT02', replace

/* ----------------------- */
/* Append AT01 & AT02 data */
/* ----------------------- */

use `tempAT01', clear
append using `tempAT02'

/* Check data */
duplicates report

/* Keep relevant variables */
keep ANON_ID OverseasCompany tangible_assets_at form sh_fixed
ren ANON_ID tax_ID

duplicates report tax_ID
bys tax_ID: gen N=_N
order N, a(tax_ID)
sort N tax_ID 			
bys tax_ID: egen max_ass=max(tangible_assets_at)
keep if max_ass==tangible_assets_at

/* Save data */
save "$data/temp/Jamaica/AT01_AT02_Assets.dta", replace

/* ----------------------------- */
/* IMPORT & CLEAN 2016-2017 DATA */
/* ----------------------------- */

/* ---------------- */
/* Import AT01 data */
/* ---------------- */

/* Load data */
import excel using "$data/input/Jamaica/OECD_Req_AT01_2016-2017.xlsx", clear first

/* Check data */
duplicates report ANON_ID ReturnFilingPeriod

/* Create variables */
gen year=year(ReturnFilingPeriod)
gen foreign_ownership=(Overseas==1)
gen tangible_assets_at=AssetValue
gen form="AT01 16/17"

/* Save data */
save "$data/temp/Jamaica/AT01_16_17.dta", replace

tempfile tempAT01
save `tempAT01', replace

/* ---------------- */
/* Import AT02 data */
/* ---------------- */

/* Load data */
import excel using "$data/input/Jamaica/OECD_Req_AT02_2016-2017.xlsx", clear first

/* Check data */
duplicates report ANON_ID ReturnFilingPeriod

/* Create variables */
gen year=year(ReturnFilingPeriod)
gen foreign_ownership=(Overseas==1)
gen tangible_assets_at=AssetValue
gen form="AT02 16/17"

/* Save data */
save "$data/temp/Jamaica/AT02_17_17.dta", replace

tempfile tempAT02
save `tempAT02', replace

/* ---------- */
/* APPEND ALL */
/* ---------- */

use `tempAT01', clear
append using `tempAT02'

ren Overseas OverseasCompany
ren ANON_ID tax_ID

append using "$data/temp/Jamaica/AT01_AT02_Assets.dta"

/* Check data */
drop max_ass N

replace year=2018 if year==.

sort tax_ID year

keep OverseasCompany tangible_assets_at tax_ID year form sh_fixed

/* Keep most recent year */
bys tax_ID: egen m_y=max(year)
keep if year==m_y
drop m_y

/* Save data */
save "$data/input/Jamaica/AT01_AT02_Assets_16_18.dta", replace