*===============================================================================
* File name: 		CIT_CRI.do
* 
* Description:		This do-file creates the dataset CRI_withvars.csv. 
*
* Input:  					
*					$data/input/Costa Rica/renta.txt 
*					$data/input/Costa Rica/SIIAT_RENTA_`i'.txt.txt 
*					$data/input/Costa Rica/D101_Renta_SIIAT_PF2016.txt 
*					$data/input/Costa Rica/id_convertor_CRI 
*					$data/input/Costa Rica/SAP_RENTA_1.txt 
*					$data/input/Costa Rica/SAP_RENTA_2.txt 
*					$data/input/Costa Rica/D101_Renta_SAP_PF2016.xlsx 
*					$data/input/Costa Rica/D101_Renta_SAP_PF`i'.del 
*					$data/input/Costa Rica/c_clase.dta 
*					$data/input/Costa Rica/RENTA_VENTAS_RUT_PDOS_2008_2016.xlsx
*					$data/input/Costa Rica/a_contribuyentes 
*					$data/input/Costa Rica/Contribuyentes.txt 
*					$data/input/Costa Rica/vD101_Renta_`i'.txt 
*					$data/input/Costa Rica/Diccionario de tablas.xlsx 
*					$data/input/Costa Rica/2021-08-13 Datos identificativos_Final.xlsx 
*					$data/input/Costa Rica/orbis_ids_multinationals.txt 
*					$data/input/Costa Rica/CRI_Lasso_Estimates.txt 
*					$data/input/Costa Rica/Contribuyentes.txt 
*					$data/input/Costa Rica/Listado_contribuyentes_zona_franca.xlsx
*
* Output:
*					$data/output/Costa Rica/CRI_withvars.csv
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

********************************************************************************
****************************** LEGAL ENTITIES **********************************
********************************************************************************

********************************************************************************
************************************ SIIAT *************************************
********************************************************************************

program breakdown_siiat
******** SELECT AND CREATE VARIABLES ********
* GROUP 0
	* Genenerate year variable
generate year=reverse(substr(reverse(d_periodo),1,4))
destring year, replace

	* Check for duplicates and drop
duplicates report year tax_ID // No duplicates

* GROUP 1: INCOMES
	* Turnover and other income 
egen turnover = rowtotal(p_ventas p_honorarios p_servicios), missing
replace turnover = . if p_ventas==. & p_honorarios==. & p_servicios==.

egen other_income = rowtotal(p_otros_ing p_dividendos p_rendimiento p_comisiones p_alquileres), missing
	* Exempt income
gen exempt_income = p_ingresos_ng 

* Dividend income	
gen dividend_income=p_dividendos
gen dividend_exempt=.

	* Total income (turnover + other_income)
egen total_income =  rowtotal(turnover other_income), missing	
	* Taxable income (-exempt income)
gen taxable_income = p_renta_bruta

* GROUP 2: COST ITEMS
	* Cost of goods sold
gen cogs = p_costo_vta	
	* Labor Inputs
gen labor_inp = . 
	* Material Inputs
gen material_inp = p_costo_vta
	* Selling, admin and other operating costs
gen operating_inp = p_gto_ventas
	* Capital Inputs
gen capital_inp = .
	* Financial Inputs
gen financial_inp = p_gto_finan   
	* Depreciation 
gen depreciation = p_depreciacion
gen acc_depreciation = .
	* Other Inputs
gen other_inp = p_costos_otros
	* Non deductible Inputs
gen non_deduc_inp = .  

 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing
gen tot_cost_dataset = p_tot_costos
gen tot_cost = p_tot_costos
replace tot_cost = tot_cost*-1 if tot_cost<0

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)   

	* Interests paid
	gen interest_payments=p_gto_finan
	
	* Inventory
	gen inventory=p_inventarios
	
* GROUP 3: PROFITS
	* Gross profit
gen gross_profit = total_income - cond(missing(cogs), 0, cogs)
	* Net profit	
gen net_profit = total_income - cond(missing(tot_cost), 0, tot_cost)

	* Taxable profit
gen taxable_profit = p_gravable // after all adjustment
gen taxable_profit_built = taxable_income - cond(missing(deductible_cost), 0, deductible_cost) // after all adjustment

* GROUP 4: GROSS & NET TAX BASE
	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
gen loss_carryforward = . 
	* Other Deductions (always from tax base)
gen other_ded_taxbase = . 
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base_built = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
gen gross_tax_base = p_gravable

	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base_built = gross_tax_base - cond(missing(loss_carryforward), 0, loss_carryforward)
gen net_tax_base = p_gravable


* GROUP 5: GROSS & NET TAX LIABILITY
	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = p_impto_renta 

	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
egen investment_taxliab = rowtotal(p_cre_activos p_cre_contratos_turi ///
     p_cre_contrato_prod p_cre_contrato_for p_exo_con_tur  ///
    p_exo_con_exp), missing
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = p_exo_son_fra
	* Other credit and allowances from tax liability
egen other_cred_taxliab = rowtotal(p_otros_cre p_exo_otro_com), missing
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing

	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)

	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
	* Add up partial/advance payments
gen partial_advanced_pay = p_pagos_p
	* Add withholding 
egen withholding = rowtotal(p_retencion_20 p_retencion_2 p_otros_ret), missing
	* Other creditable tax payments
gen other_cred_tax_pay = .

	* Tax to remit
gen tax_to_remit = p_impto_pagar

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

gen FEZ = 0 
replace FEZ =1 if p_exo_son_fra !=0 & p_exo_son_fra!=.

gen total_assets = p_tot_activos

egen tang_assets=rowtotal(p_efectivo p_acciones p_inventarios p_activos p_depreciacion), missing
egen admin_sales_costs=rowtotal(p_gto_ventas), missing 

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"

************* KEEP VARIABLES WE NEED *************
	* Create locals to keep variables
local group0 year tax_ID  
local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
local group7 admin_sales_costs tang_assets p_cre_famili p_pen_volun interest_payments inventory

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' d_periodo d_recepcion_banco nro_declaracion FEZ total_assets

end


*************** DATA 2006-2015 ******************
			set more off 
			
			*Load data
			insheet using "$data/input/Costa Rica/renta.txt",  delim("|") clear
			
			drop if model==0 & version==.
			drop modelo fecha_carga
			duplicates drop
			tab version
			gen month=substr(d_period,6,2)
			drop if month!="12"
			drop month
			foreach var in 	p_efectivo-p_impto_neto p_imp_desp-p_comisiones ///
							p_impto_ex-p_imp_ord_ex p_exo_con_tur-p_exo_otro p_impto_pagar p_efectivo p_acciones p_inventarios p_activos p_gto_ventas {
							cap destring `var', replace dpcomma
			}	
			
			*New identifying vars
			cap replace d_recepcion_banco=d_recepcion_adm if d_recepcion_banco=="" 
			
			* Rename
			rename nro_idu_contrib tax_ID
			rename p_depresiacion p_depreciacion
			
			* Program breakdown variables
			breakdown_siiat 
			replace year=substr(d_periodo,1,4)
			destring year, replace
			
			* Drop duplicates
			drop if missing(tax_ID)
			drop if year>2015 | year<2006
			duplicates drop tax_ID- tax_to_remit, force
			
			* Keep only latest declaration
			so tax_ID year nro_declaracion
			drop if tax_ID==tax_ID[_n+1] & year==year[_n+1] & nro_declaracion!=nro_declaracion[_n+1]
			generate fdate=daily(d_recepcion_banco,"YMD")
			format fdate %td
			g dataset=1

			save  "$data/temp/Costa Rica/renta1.dta", replace 

****************************** SIIAT 2011-2016 *********************************
	* We'll create temporary files for each year
	forvalues  i=2011/2016{
insheet using  "$data/input/Costa Rica/SIIAT_RENTA_`i'.txt", clear
	* ID
rename nro_idu_contrib tax_ID
	* Program breakdown variables
breakdown_siiat 
g dataset = 2
tempfile siiat`i'
save `siiat`i''
}

	* Append datasets
append using `siiat2011' `siiat2012' `siiat2013' `siiat2014' `siiat2015' 
	tempfile siiat1
	save `siiat1'

*********************************  SIIAT data 2016 *****************************
insheet using "$data/input/Costa Rica/D101_Renta_SIIAT_PF2016.txt", clear
	* Rename variables in raw data
rename nroidusiiat tax_ID 
foreach var of varlist p_honorarios-p_impto_renta p_exo_son_fra p_exo_otro_com p_cre_famili-p_impto_neto p_impto_pagar p_tot_activos p_efectivo p_acciones p_inventarios p_activos p_gto_ventas p_comisiones p_alquileres {
	cap	replace `var'=subinstr(`var',",","",.)
	cap destring `var', replace dpcomma
}
	* Program breakdown variables
breakdown_siiat 
g dataset = 3
	* Save data
tempfile siiat2
	save `siiat2'
	
**************** Combine all SIIAT datasets and drop duplicates ***************
clear 
use  `siiat1', clear
append using `siiat2', force //`siiat3'

	* Create date variables
generate fdate=daily(d_recepcion_banco,"MDY")
format fdate %td

	*Create first and last filing date per taxpayer and period
bys tax_ID year: egen first_decl_date=min(fdate)
bys tax_ID year: egen  last_decl_date=max(fdate)
							
	*Drop duplicates: keep only the latest declaration
drop if tax_ID==. | year==.
so tax_ID year fdate, stable
drop if tax_ID==tax_ID[_n+1] & year==year[_n+1] & fdate<fdate[_n+1]

duplicates drop tax_ID year nro_declaracion fdate, force

so tax_ID year nro_declaracion
drop if tax_ID==tax_ID[_n+1] & year==year[_n+1] & nro_declaracion!=nro_declaracion[_n+1]
duplicates drop tax_ID year nro_declaracion, force
duplicates drop tax_ID year, force
sort tax_ID year, stable


save  "$data/temp/Costa Rica/siiaat.dta", replace 

****
use  "$data/temp/Costa Rica/siiaat.dta", clear 
append using "$data/temp/Costa Rica/renta1.dta"
duplicates drop tax_ID year nro_declaracion, force
* Keep latest declaration
so tax_ID year fdate, stable
drop if tax_ID==tax_ID[_n+1] & year==year[_n+1] & fdate<fdate[_n+1]
duplicates tag tax_ID year, gen(flag)
drop if flag ==1 & dataset == 2 // keep first dataset for duplicates between renta1 ansd siiat, less missing

gen siiat=1
label var siiat "Observation comes from SIIAT data (1=Yes)"

save  "$data/temp/Costa Rica/siiaat_renta1.dta", replace 

********************************************************************************
************************************ SAP ***************************************
********************************************************************************			
*Merge summer 2018 datsets with ID convertor (converts nrointernoid into nroidusiiat)
cap program drop merge_id_convertor
program define merge_id_convertor 
	syntax [, invar(varname) out(string )]
	tokenize `varlist'
	cap ren `invar' _nrointernoid
	cap ren nrointernoid _nrointernoid // default forinvar
	merge m:1 _nrointernoid using "$data/input/Costa Rica/id_convertor_CRI", keep(1 3)
	sum _merge
	assert r(mean)==3
	drop _nrointerno _mer
	cap ren nroidusiiat `out'
	cap ren nroidusiiat idu 
end	

cap program drop breakdown_sap
 program breakdown_sap
******** SELECT AND CREATE VARIABLES ********
	* Check for duplicates and drop
duplicates report year tax_ID // No duplicates

* GROUP 1: INCOMES
	* Turnover and other income 
egen turnover =rowtotal(a_20_ingres_venta_bien a_21_ingres_venta_serv a_22_servi_profes_hono), missing
replace turnover = . if a_20_ingres_venta_bien==. & a_21_ingres_venta_serv==. & a_22_servi_profes_hono==.

egen other_income = rowtotal(a_23_comisiones a_24_alquileres a_25_interes_y_rend_fin a_26_dividen_y_partici a_27_otros_ingresos a_28_devoluc_y_descuen), missing
	* Exempt income
gen exempt_income = a_29_ingresos_no_grava

* Dividend income
gen dividend_income=a_26_dividen_y_partici
gen dividend_exempt=a_101_dividen_y_partic 

	* Total income (turnover + other_income)
egen total_income =  rowtotal(turnover other_income), missing	
	* Taxable income (-exempt income)
gen taxable_income = a_30_total_ingres_brut



* GROUP 2: COST ITEMS
	* Cost of goods sold
gen cogs = a_31_costo_de_ventas
	* Labor Inputs
egen labor_inp = rowtotal(a_120_sueldos_y_salari  a_130_sueldos_y_salari ), missing
	* Material Inputs
gen material_inp =a_31_costo_de_ventas
	* Selling, admin and other operating costs
egen operating_inp = rowtotal(a_35_gasto_vent_y_dist a_34_gasto_gene_y_admi a_32_costo_de_producci ), missing
	* Capital Inputs
gen capital_inp =.
	* Financial Inputs
egen financial_inp = rowtotal(a_37_otros_gast_financ a_36_gastos_intereses), missing 
	* Depreciation 
egen depreciation = rowtotal(a_126_gasto_p_deprecia a_136_gastos_por_depre), missing 
gen acc_depreciation = .
	* Other Inputs
gen other_inp = . 
	* Non deductible Inputs
gen non_deduc_inp = a_41_gast_no_ded_inc_a

 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing
gen tot_cost_dataset = a_33_total_costos
gen tot_cost = tot_cost_dataset
	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = a_42_tot_gast_y_otr_de 
gen deductible_cost_built = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp) 

	* Interests paid
	gen interest_payments=a_36_intereses
	
	* Inventory
	gen inventory=a_156_inventarios

* GROUP 3: PROFITS
	* Gross profit
gen gross_profit = total_income - cond(missing(cogs), 0, cogs) 
	* Net profit
gen net_profit = total_income - cond(missing(tot_cost), 0, tot_cost)

	* Taxable profit
gen taxable_profit = . // after all adjustment
gen taxable_profit_built = taxable_income - cond(missing(deductible_cost), 0, deductible_cost) // after all adjustment

* GROUP 4: GROSS & NET TAX BASE
	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
gen loss_carryforward = . 
	* Other Deductions (always from tax base)
egen other_ded_taxbase = rowtotal(a_40_otras_deducciones a_39_apor_reg_vol_pens a_38_deduc_perdid_dife), missing 
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base_built = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
gen gross_tax_base = a_43_renta_neta
replace gross_tax_base = a_44_perdida_neta*-1 if gross_tax_base==0

	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base_built = gross_tax_base - cond(missing(loss_carryforward), 0, loss_carryforward)
gen net_tax_base = gross_tax_base


* GROUP 5: GROSS & NET TAX LIABILITY
	* Gross tax liability
gen gross_tax_liability = a_45_impuesto_de_renta 
	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
egen investment_taxliab = rowtotal(a_47_otr_exone_per_ley), missing
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = a_46_exoner_zona_franc
	* Other credit and allowances from tax liability
egen other_cred_taxliab = rowtotal (a_50_otr_cred_fis_perm), missing
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing


	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = a_51_impto_del_periodo+a_49_creditos_familiar
gen net_tax_liability_built = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)

	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)



* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
	* Add up partial/advance payments
egen partial_advanced_pay = rowtotal( a_55_pago_a_cta_de_imp a_54_pagos_parcs_renta), missing
	* Add withholding 
egen withholding = rowtotal(a_52_retenc_2_por_cien a_53_retenc_3_por_cien), missing
	* Other creditable tax payments
gen other_cred_tax_pay = .

	* Tax to remit
gen tax_to_remit = a_56_impto_neto_period
replace tax_to_remit = a_57_saldo_a_fav_perio*-1 if tax_to_remit == 0

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

/* ASSETS */
egen tang_assets=rowtotal(a_150_efecti_y_equi_ef a_151_inversiones a_152_cuenta_p_cobr_cl a_153_cuenta_p_cobr_so a_154_cuenta_p_cobr_ot a_155_accion_y_apor_so a_156_inventarios a_157_activos_fijos a_158_deprecia_acti_fi), missing

egen admin_sales_costs=rowtotal(a_34_gasto_gene_y_admi a_35_gasto_vent_y_dist), missing

gen total_assets = a_164_total_activo

gen FEZ = 0 
replace FEZ =1 if a_46_exoner_zona_franc !=0 & a_46_exoner_zona_franc!=.

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"

************* KEEP VARIABLES WE NEED *************
	* Create locals to keep variables
local group0 year tax_ID  
local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
local group7 a_34_gasto_gene_y_admi a_35_gasto_vent_y_dist a_120_sueldos_y_salari a_130_sueldos_y_salari a_138_totales a_128_totales sap tang_assets admin_sales_costs a_49_creditos_familiar a_39_apor_reg_vol_pens interest_payments inventory

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' d_periodo a_01_num_declaracion fdate FEZ total_assets

end
	
* Insheeting the different versions of the datasets
clear 
set more off


foreach version in 1 2 3 {	
	if `version'==1 {
		
		insheet using "$data/input/Costa Rica/SAP_RENTA_1.txt", clear
		generate fdate=daily(a_98_fecha_recepcion,"MDYhm")
		format fdate %td
		rename idu nro_idu_contrib
		tempfile part1
		save `part1'
		
		insheet using "$data/input/Costa Rica/SAP_RENTA_2.txt", clear
		generate fdate=daily(a_98_fecha_recepcion,"MDYhm")
		format fdate %td
		ren idu nro_idu_contrib
		append using `part1'

		}
	if `version'==2 {
		
		import excel using "$data/input/Costa Rica/D101_Renta_SAP_PF2016.xlsx", firstrow case(lower) clear
		rename nroidusiiat nro_idu_contrib	
		ren a_98_fecha_recepcion fdate
		format fdate %td
		
		}
	if `version'==3 {
		forvalues i=2014/2017{
			
			insheet using "$data/input/Costa Rica/D101_Renta_SAP_PF`i'.del", clear delim("|")	
			generate fdate=daily(a_98_fecha_recepcion,"DMYhm")
			tempfile prelim_sat_`i'
			save `prelim_sat_`i''
			
			}
		append using `prelim_sat_2014' `prelim_sat_2015' `prelim_sat_2016', force
		merge_id_convertor, invar(nrointernoid) out(nro_idu_contrib)  
		unique nro_idu_con
		}
		tempfile sap`version'
		sa `sap`version'', replace
		}
	* Append
	use `sap1'
	append using  `sap2' `sap3', force
	
rename nro_idu_contrib tax_ID
rename a_02_periodo_fiscal year	
rename a_98_fecha_recepcion d_periodo

gen sap=1
label var sap "Observation comes from SAP data (1=Yes)"

/* Explore dividends and exempted dividend income */
egen a_103_built=rowtotal(a_100_inter_y_rend_fin a_101_dividen_y_partic a_102_otr_ingre_no_gra), missing
replace a_103_built= a_103_tot_ingre_no_gra if a_103_built==.
replace a_103_built=. if a_103_tot_ingre_no_gra==.

// Share of exempted dividends out of the total exempted income
gen sh_div_exemp_total=a_101_dividen_y_partic/a_103_tot_ingre_no_gra*100
replace sh_div_exemp_total=. if a_101_dividen_y_partic>a_26_dividen_y_partici

gen sh_div_exemp_totaldiv=a_101_dividen_y_partic/a_26_dividen_y_partici*100
replace sh_div_exemp_totaldiv=. if a_26_dividen_y_partici==0
replace sh_div_exemp_totaldiv=. if a_26_dividen_y_partici==.
replace sh_div_exemp_totaldiv=. if a_101_dividen_y_partic>a_26_dividen_y_partici

egen turnover =rowtotal(a_20_ingres_venta_bien a_21_ingres_venta_serv a_22_servi_profes_hono), missing
replace turnover = . if a_20_ingres_venta_bien==. & a_21_ingres_venta_serv==. & a_22_servi_profes_hono==.
egen other_income = rowtotal(a_23_comisiones a_24_alquileres a_25_interes_y_rend_fin a_26_dividen_y_partici a_27_otros_ingresos a_28_devoluc_y_descuen), missing
egen total_income =  rowtotal(turnover other_income), missing	

xtile quantile_div=total_income if total_income>0 & a_26_dividen_y_partici>0, n(10)
bys quantile_div: egen mean_q_sh_div=mean(sh_div_exemp_total)
bys quantile_div: egen mean_q_sh_divonly=mean(sh_div_exemp_totaldiv)

drop turnover other_income total_income

	* Program
breakdown_sap 

/* Compute wage related variables */
egen a_34_35_b=rowtotal(a_34_gasto_gene_y_admi a_35_gasto_vent_y_dist), missing
egen a_128_138_b=rowtotal(a_128_totales a_138_totales), missing
egen total_wages=rowtotal(a_120_sueldos_y_salari a_130_sueldos_y_salari), missing

gen sh_wages_admin_costs=total_wages/a_128_138_b*100
gen turnover_millions=turnover/1000000

xtile quantile=turnover_millions if turnover>1, n(10)
bys quantile: egen mean_q_sh_wages=mean(sh_wages_admin_costs)

drop if  year ==.| tax_ID ==. // Drop missing values
gen ltu =1

	*Create first and last filing date per taxpayer and period
bys tax_ID year: egen first_decl_date=min(fdate)
bys tax_ID year: egen  last_decl_date=max(fdate)

	*Drop duplicates and keep latest declaration only  
tab year
duplicates drop tax_ID year fdate, force
tab year
sort tax_ID year fdate
drop if tax_ID==tax_ID[_n+1] & year==year[_n+1] & fdate<fdate[_n+1]
tab year
duplicates report  tax_ID year 
duplicates report  tax_ID year, force 		
drop if tax_ID==. | year==.
tempfile sapTOTAL
save `sapTOTAL', replace

	
********************************************************************************
***************************** Combine SIIAT & SAP ******************************
********************************************************************************

	* Append SIIAT and SAP
use "$data/temp/Costa Rica/siiaat_renta1.dta", clear
append using `sapTOTAL'
duplicates report tax_ID year fdate
duplicates tag tax_ID  fdate year, g(d1)
drop if ltu==. & d1==1
drop d1
duplicates tag tax_ID  year, g(d1)
drop if nro_declaracion == . & d1==1
drop d1

	*Generate new variables: country name and entity type
generate country = "CRI" 
generate entity = "Legal"

merge m:1 tax_ID using "$data/input/Costa Rica/c_clase.dta"
keep if _merge==3

drop  d_recepcion* fdate first_decl_date last_decl_date /// Drop variables we don't need
     ltu nro_declaracion _merge d_periodo 
	 
tempfile CIT_vars
save `CIT_vars'


****  Add sectors
	
/* Here, we read files where sector variable is available. We will read multiple years
	and if a sector is not found in one year, then we go to the other year and keep
	that one, if available */

set excelxlsxlargefile on

forvalues  i=2008/2016{
import excel using "$data/input/Costa Rica/RENTA_VENTAS_RUT_PDOS_2008_2016.xlsx", clear firstrow sheet("`i'")
ren IDU idu
gen year=`i'
sort idu OBLIGA
drop if idu==idu[_n-1] & OB!=OB[_n-1]
tempfile temp`i'
sa `temp`i''
} 
append using `temp2008' `temp2009' `temp2010' `temp2011' `temp2012' `temp2013' ///
             `temp2014' `temp2015'
	
save "$data/temp/Costa Rica/temp_sector.dta", replace

use "$data/temp/Costa Rica/temp_sector.dta", clear
replace ACT = ACTIVIDAD if missing(ACT)
drop ACTIVIDAD
sort idu year
order year
drop if year!=year[_n-1] & idu==idu[_n-1] 
drop year
duplicates report idu
duplicates drop idu, force

tostring ACT, replace
gen division=reverse(substr(reverse(ACT),5,6))
drop if CODIGOSECTORECON == "Z" 
										
gen section = CODIGOSECTORECON
replace section = "C" if CODIGOSECTORECON == "D"
replace section = "I" if CODIGOSECTORECON == "H"
replace section = "L" if CODIGOSECTORECON == "K"
replace section = "D" if CODIGOSECTORECON == "E"
replace section = "H" if CODIGOSECTORECON == "I"
replace section = "K" if CODIGOSECTORECON == "J"
replace section = "S" if CODIGOSECTORECON == "O"
replace section = "O" if CODIGOSECTORECON == "L"
replace section = "P" if CODIGOSECTORECON == "M"
replace section = "B" if CODIGOSECTORECON == "C"
replace section = "T" if CODIGOSECTORECON == "P"
replace section = "U" if CODIGOSECTORECON == "Q"
replace section = "Q" if CODIGOSECTORECON == "N"
replace section = "A" if CODIGOSECTORECON == "B"

* CIIU4. Standardization. 
gen descr_section = section 
replace descr_section = "Agricultura, ganaderia, silvicultura y pesca" if section == "A"
replace descr_section = "Explotacion de minas y canteras" if section == "B"
replace descr_section = "Industrias manufactureras" if section == "C"
replace descr_section = "Suministro de electricidad, gas, vapor y aire acondicionado" if section == "D"
replace descr_section = "Suministro de agua, evacuacion de aguas residuales, gestion de desechos y descontaminacion" if section == "E"
replace descr_section = "Construccion" if section == "F"
replace descr_section = "Comercio al por mayor y al por menor; reparacion de vehiculos automotores y motocicletas" if section == "G"
replace descr_section = "Transporte y almacenamiento" if section == "H"
replace descr_section = "Actividades de alojamiento y servicio de comidas" if section == "I"
replace descr_section = "Informacion y comunicaciones" if section == "J"
replace descr_section = "Actividades financieras y de seguros" if section == "K"
replace descr_section = "Actividades inmobiliarias" if section == "L"
replace descr_section = "Actividades profesionales, cientificas y tecnicas" if section == "M"
replace descr_section = "Actividades de servicios administrativos y de apoyo" if section == "N"
replace descr_section = "Administracion publica y defensa; planes de seguridad social de afiliacion obligatoria" if section == "O"
replace descr_section = "Ensenanza" if section == "P"
replace descr_section = "Actividades de atencion de la salud humana y de asistencia social" if section == "Q"
replace descr_section = "Actividades artisticas, de entretenimiento y recreativas" if section == "R"
replace descr_section = "Otras actividades de servicio" if section == "S"
replace descr_section = "Actividades de los hogares como empleadores; actividades no diferenciadas de los hogares como productores de bienes y servicios para uso propio" if section == "T"
replace descr_section = "Actividades de organizaciones y organos extraterritoriales" if section == "U"

* We will merge it with other firm characteristics so let's rename the identifier
rename idu nro_idu_contrib 
merge m:1 nro_idu_contrib using "$data/input/Costa Rica/a_contribuyentes.dta"

rename nro_idu_contrib  tax_ID 
gen c_clase_contrib = subinstr(TIPO," ","",.)

drop OBLIGA  CED NOM ADM PERÍODO CODIGOSECTORECON NOMSECTORECON CEDULA NOMBRE ///
     c_c_acti c_c_clase TIPO  _merge

merge 1:m tax_ID using `CIT_vars', keep(3)

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************
keep if c_clase_contrib == "J" 

	* Order, sort, and drop variables
order year, after(tax_ID)
order division section descr_section c_c_admin c_c_provincia c_c_canton c_c_distrito, after(entity)
sort tax_ID year, stable
drop c_clase_contrib  _merge

save "$data/temp/Costa Rica/legal_CRI", replace

***** VARIOUS TAXPAYER CHARACTERISTICS**************

		/* Contribuyentes main data */ 
		insheet using "$data/input/Costa Rica/Contribuyentes.TXT", delim("|") clear

		/* Numerics - fill in missings (only c_clase always defined) */
			foreach var in c_acti c_tamano f_situa c_admon c_provincia c_canton c_distri { // ///
			*nro_telefono nro_fax   {
			sort  nro_idu  `var'
			replace `var'=`var'[_n-1] if `var'==. & nro_idu==nro_idu[_n-1]
			replace `var'=`var'[_n-2] if `var'==. & nro_idu==nro_idu[_n-2]
			replace `var'=`var'[_n-3] if `var'==. & nro_idu==nro_idu[_n-3]
			}
		/* Strings - fill in missings  */
			cap foreach var in n_ubicacion n_barrio n_calle_avenida nro_casa nro_ofic_postal n_email  {
			sort  nro_idu `var'
			replace `var'=`var'[_n+1] if `var'=="" & nro_idu==nro_idu[_n+1]
			replace `var'=`var'[_n+2] if `var'=="" & nro_idu==nro_idu[_n+2]
			replace `var'=`var'[_n+3] if `var'=="" & nro_idu==nro_idu[_n+3]
			}
			duplicates drop
		/* Created 2nds for all variables */
			sort nro_idu 
			foreach var in c_acti c_tamano f_situa c_admon c_provincia c_canton c_distri {
			gen _2nd_`var'=. 
			replace _2nd_`var'=`var'[_n+1] if `var'!=. & `var'[_n+1]!=. & `var'!=`var'[_n+1] & nro_idu==nro_idu[_n+1]
			}
			cap foreach var in c_clase n_ubicacion n_barrio n_calle_avenida nro_casa nro_ofic_postal n_email  {
			gen _2nd_`var'="" 
			replace _2nd_`var'=`var'[_n+1] if `var'!="" & `var'[_n+1]!="" & `var'!=`var'[_n+1] & nro_idu==nro_idu[_n+1]
			}
			drop if nro_idu==nro_idu[_n-1]
			sort nro_idu   

			keep nro_idu_contrib c_acti_pri c_tamano_contrib f_situac_contri ///
			c_clase_contrib c_admon_tribut c_provincia c_canton c_distrito
			
			sort nro_idu   

			ren c_acti_pri c_actividad
			sort c_actividad

			ren c_admon c_admi
			keep nro_idu c_acti c_clase c_provincia c_canton c_distrito c_admi
			foreach var in c_acti c_clase c_provincia c_canton c_distrito  c_admi {
			ren `var' c_`var'
			}
			sort nro_idu
			rename nro_idu tax_ID
			save "$data/temp/Costa Rica/a_contribuyentes.dta", replace

* Final adjustments
use "$data/temp/Costa Rica/legal_CRI", clear

merge m:1 tax_ID using "$data/temp/Costa Rica/a_contribuyentes.dta"
sort tax_ID year, stable
drop if _merge == 2
drop if year == 2017

* capital
gen capital = . if c_c_provincia == . 
replace capital = 0 if c_c_provincia == . 
replace capital = 1 if c_c_provincia == 1 & c_c_canton == 1 // San Jose Province, San Jose. 
drop _merge
save "$data/temp/Costa Rica/temp_2006_2016.dta", replace

******************************************************************
******************************************************************
* 							ADD 2018 to 2020
******************************************************************
******************************************************************


forvalues  i=2018/2020{
	 di in red "YEAR: `i'"
     import delimited "$data/input/Costa Rica/vD101_Renta_`i'.txt", delimiter ("|") varnames(1) clear 
	 tempfile renta_`i'
	 save `renta_`i''
}
clear
forvalues  i=2018/2020{
append using `renta_`i''
}

* Duplicates
* Keep only last declaration rectified
keep if tipodeclaracion == "Ultima"
duplicates report nroanoperiodo nrointernoid

*-------------------------------------------
rename nrointernoid tax_ID
rename nroanoperiodo year

* GROUP 1: INCOMES
	* Turnover and other income 
egen turnover=rowtotal(ventabienesyservnoprof servprofyhonorarios), missing

egen other_income = rowtotal(comisiones interesesrendimientos dividendosparticipaciones alquileres otrosingresosdiferentesanteriore), missing
	* Exempt income
gen exempt_income = ingresosnogravincluienanteriores

	* Dividend income	
gen dividend_income=dividendosparticipaciones
gen dividend_exempt=.

	* Total income (turnover + other_income)
egen total_income =  rowtotal(turnover other_income), missing	
	* Taxable income (-exempt income)
gen taxable_income = totalrentabruta


* GROUP 2: COST ITEMS
	* Cost of Goods sold
gen cogs = costoventas	
	* Labor Inputs
gen labor_inp = .
	* Material Inputs
gen material_inp =costoventas
	* Selling, admin and other operating costs
egen operating_inp = rowtotal(gastosventasadministrativos ), missing
	* Capital Inputs
gen capital_inp =.
	* Financial Inputs
egen financial_inp = rowtotal(interesesgastosfinancieros), missing 
	* Depreciation 
egen depreciation = rowtotal(deprecamortizagotamiento), missing 
gen acc_depreciation = .
	* Other Inputs
egen other_inp = rowtotal(otroscostosgastosdeducciones aportevoluntarioregpensionescomp), missing 
	* Non deductible Inputs
gen non_deduc_inp = .

 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing
gen tot_cost_dataset = totalcostosgastosdeducciones
gen tot_cost = tot_cost_dataset

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost = . 
gen deductible_cost_built = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp) 

	* Interests paid
	gen interest_payments=intereses
	
	* Inventory
	gen inventory=inventarios

* GROUP 3: PROFITS
	* Gross profit
gen gross_profit = total_income - cond(missing(cogs), 0, cogs)	
	* Net profit
gen net_profit = total_income - cond(missing(tot_cost), 0, tot_cost)

	* Taxable profit
gen taxable_profit = rentaneta // after all adjustment

gen taxable_profit_built = taxable_income - cond(missing(deductible_cost_built), 0, deductible_cost_built) // after all adjustment

replace taxable_profit = taxable_profit_built if taxable_profit==0

* GROUP 4: GROSS & NET TAX BASE
	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
gen loss_carryforward = . 
	* Other Deductions (always from tax base)
gen other_ded_taxbase =. 
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base_built = taxable_profit - cond(missing(tot_deduc_taxbase), 0, tot_deduc_taxbase)
gen gross_tax_base = taxable_profit

	* Net tax base (gross_tax_base - loss_carryforward)
gen net_tax_base_built = gross_tax_base - cond(missing(loss_carryforward), 0, loss_carryforward)
gen net_tax_base = gross_tax_base


* GROUP 5: GROSS & NET TAX LIABILITY
	* Gross tax liability (net tax base*CIT rate)
gen gross_tax_liability = impuestorenta 
	* Credits for foreign taxes paid
gen cred_foreign_tax = .	
	* Investment credits from tax liability
egen investment_taxliab = rowtotal(exoneraciónzonafranca exoneracióncontratoturístico  exoneracióncontratoexportación), missing
	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
egen other_cred_taxliab = rowtotal( exoneraciónotrosconcepto), missing
	* Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing
	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = impuestorentadespuésexoneracione-otroscréditos
gen net_tax_liability_built = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)
	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)


* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
	* Add up partial/advance payments
gen partial_advanced_pay = .
	* Add withholding 
gen withholding = .
	* Other creditable tax payments
egen other_cred_tax_pay = rowtotal(créditoinversióncontratoturístic créditoinversióncontratoproducci ///
créditoinversióncontratoforestal créditofamiliar otroscréditos), missing

	* Tax to remit
gen tax_to_remit = totalimpuestoneto

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

gen FEZ = 0 
replace FEZ =1 if exoneraciónzonafranca !=0 & exoneraciónzonafranca!=.

gen total_assets = totalactivoneto

gen only_depreciation=deprecamortizagotamiento*0.95

egen tang_assets=rowtotal(activosfijoscondeprecacumdescont), missing
egen admin_sales_costs=rowtotal(gastosventasadministrativos), missing

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"

/* Save full data */
tempfile temp_2018_20
save `temp_2018_20'

************* KEEP VARIABLES WE NEED *************
	* Create locals to keep variables
local group0 year tax_ID  
local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab
local group7 admin_sales_costs tang_assets aportevoluntarioregpensionescomp  bacumanualnosujetoimpuestosalari créditofamiliar inventory interest_payments

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' dtfechapresentacion período declaracionrectificada  FEZ total_assets
	
gen d_18_20=1

label var d_18_20 "Observation comes from most recent data (1=Yes)"

save "$data/temp/Costa Rica/temp_2018_20.csv", replace 

*** FIRM CHARACTERISTICS

* 1) Sectors Dictionary: gives the 5-6 digits code with their description
	import excel "$data/input/Costa Rica/Diccionario de tablas.xlsx", sheet("Código Act Económicas") firstrow clear
	duplicates drop
	drop if missing(CódigoActividad)
	tempfile sectors
	save `sectors' // ready to be merged at the 5 or 6 digit codes

	// Create a less granulated sections
	tostring CódigoActividad, gen(code)
	gen division = substr(code, 1, 2) 
	replace division = substr(code, 1, 1) if strlen(code) == 5
	drop if SectorEconómico == "Z" | SectorEconómico == "W"
	replace SectorEconómico = "K"	 if division == "71"
	replace SectorEconómico = "L"	 if division == "75" 
	replace SectorEconómico = "O"	 if division == "91" 
	replace SectorEconómico = "O"	 if division == "92" 
	collapse (count) CódigoActividad , by(division SectorEconómico)
	sort SectorEconómico
	drop if division == "90"
	destring division, replace
	tempfile sectors_2d
	save `sectors_2d' 

* 2) Prepare the Final Batch to match with the sectors, based on tax_ID
	import excel "$data/input/Costa Rica/2021-08-13 Datos identificativos_Final.xlsx", sheet("Datos") firstrow clear
	rename nro_InternoID tax_ID
	duplicates drop
	
	* Create the 2d-division variables for the sectors that won't match
	replace Codigo_AEP_Activa = "." if  Codigo_AEP_Activa=="NULL"
	gen division = substr(Codigo_AEP_Activa, 1, 2) 
	replace division = substr(Codigo_AEP_Activa, 1, 1) if strlen(Codigo_AEP_Activa) == 5
	destring division, replace
	destring Codigo_AEP_Activa, gen(CódigoActividad)
	drop if CódigoActividad == .

	* Merge with the file 1)i. sectors
	merge m:1 CódigoActividad using `sectors'
	drop _merge
	
	* Merge with the file 1)ii. sectors_2d
	merge m:1 division using `sectors_2d'
	replace SectorEconómico = "W" if division == 96
	drop _merge
	drop if missing(tax_ID)
	
* 3) Adapt to CIIU4. Standardization
	gen section = SectorEconómico
	replace section = "C" if SectorEconómico == "D"
	replace section = "I" if SectorEconómico == "H"
	replace section = "L" if SectorEconómico == "K"
	replace section = "D" if SectorEconómico == "E"
	replace section = "H" if SectorEconómico == "I"
	replace section = "K" if SectorEconómico == "J"
	replace section = "S" if SectorEconómico == "O"
	replace section = "O" if SectorEconómico == "L"
	replace section = "P" if SectorEconómico == "M"
	replace section = "B" if SectorEconómico == "C"
	replace section = "T" if SectorEconómico == "P"
	replace section = "U" if SectorEconómico == "Q"
	replace section = "Q" if SectorEconómico == "N"
	replace section = "A" if SectorEconómico == "B"
	replace section = "" if SectorEconómico == "Z"


	* CIIU4. Standardization. 
	gen descr_section = section 
	replace descr_section = "Agricultura, ganaderia, silvicultura y pesca" if section == "A"
	replace descr_section = "Explotacion de minas y canteras" if section == "B"
	replace descr_section = "Industrias manufactureras" if section == "C"
	replace descr_section = "Suministro de electricidad, gas, vapor y aire acondicionado" if section == "D"
	replace descr_section = "Suministro de agua, evacuacion de aguas residuales, gestion de desechos y descontaminacion" if section == "E"
	replace descr_section = "Construccion" if section == "F"
	replace descr_section = "Comercio al por mayor y al por menor; reparacion de vehiculos automotores y motocicletas" if section == "G"
	replace descr_section = "Transporte y almacenamiento" if section == "H"
	replace descr_section = "Actividades de alojamiento y servicio de comidas" if section == "I"
	replace descr_section = "Informacion y comunicaciones" if section == "J"
	replace descr_section = "Actividades financieras y de seguros" if section == "K"
	replace descr_section = "Actividades inmobiliarias" if section == "L"
	replace descr_section = "Actividades profesionales, cientificas y tecnicas" if section == "M"
	replace descr_section = "Actividades de servicios administrativos y de apoyo" if section == "N"
	replace descr_section = "Administracion publica y defensa; planes de seguridad social de afiliacion obligatoria" if section == "O"
	replace descr_section = "Ensenanza" if section == "P"
	replace descr_section = "Actividades de atencion de la salud humana y de asistencia social" if section == "Q"
	replace descr_section = "Actividades artisticas, de entretenimiento y recreativas" if section == "R"
	replace descr_section = "Otras actividades de servicio" if section == "S"
	replace descr_section = "Actividades de los hogares como empleadores; actividades no diferenciadas de los hogares como productores de bienes y servicios para uso propio" if section == "T"
	replace descr_section = "Actividades de organizaciones y organos extraterritoriales" if section == "U"

	drop NombreActividad SectorEconómico SectorEconómicoDescripción
	gen country = "CRI"
	rename Codigo_AEP_Activa ACT
	
* Save temp sectors data
	tempfile sectors_full
	save `sectors_full'

* 4) Merge to CIT data:
    merge 1:m tax_ID using "$data/temp/Costa Rica/temp_2018_20.csv"
	drop if _merge == 1 
	drop _merge
	tostring division, replace

save "$data/input/Costa Rica/temp_2018_20.dta", replace

**************************
* APPEND WITH PREVIOUS DATA

append using  "$data/temp/Costa Rica/temp_2006_2016"

/* Drop natural persons */
keep if Tipo_Identificacion == "J" | Tipo_Identificacion==""
drop if year == .

/* Cases with positive amounts in the variables filled only natural persoons */
ren aportevoluntarioregpensionescomp aportesvol
ren bacumanualnosujetoimpuestosalari acumsal 
ren a_49_creditos_familiar a49cred 
ren a_39_apor_reg_vol_pens a39apor

foreach var of varlist aportesvol acumsal créditofamiliar a49cred a39apor p_cre_famili p_pen_volun {
		bys tax_ID: egen m_`var'=max(`var')
		replace m_`var'=0 if m_`var'==.
	}

summ m_aportesvol m_acumsal m_créditofamiliar m_a49cred m_a39apor m_p_cre_famili m_p_pen_volun

drop if m_aportesvol>0 & m_aportesvol!=. & Tipo_Identificacion==""
drop if m_acumsal>0 & m_acumsal!=. & Tipo_Identificacion==""
drop if m_créditofamiliar>0 & m_créditofamiliar!=. & Tipo_Identificacion==""
drop if m_p_cre_famili>0 & m_p_cre_famili!=. & Tipo_Identificacion==""
drop if m_p_pen_volun>0 & m_p_pen_volun!=. & Tipo_Identificacion==""
drop if m_a49cred>0 & m_a49cred!=. & Tipo_Identificacion==""
drop if m_a39apor>0 & m_a39apor!=. & Tipo_Identificacion==""

/* Check obs after dropping additional cases */
tab year
count
tab Tipo_Identificacion
tab year if Tipo_Identificacion==""
count if Tipo_Identificacion=="" & year>2017
count if Tipo_Identificacion=="J" & year>2017

/* Check missing cases across years */
gen ent_t=1
replace ent_t=2 if Tipo_Identificacion=="F"
replace ent_t=0 if Tipo_Identificacion==""

tab year ent_t

* GROUP 7: FIRM CHARACTERISTICS
replace FEZ = 1 if ZonaFranca == "S" 

* Incorporation
replace Fecha_Inscripcion = "" if Fecha_Inscripcion == "NULL"
replace Fecha_Inscripcion = "9/11/2021" if Fecha_Inscripcion == "9/11/2100"

gen incorporation_date = date(Fecha_Inscripcion, "MDY")
format incorporation_date %td

gen incorporation = year(incorporation_date)
gen firm_age = year - incorporation + 1 
gen first_year = 0
replace first_year = 1 if firm_age <2 & firm_age != .
replace first_year = . if missing(incorporation)

gen foreign_ownership = Casasextrajenra 
replace foreign_ownership = 1 if Capital_extranjero == 1

gen capital_city = capital

* Other:
gen nb_employee = .
gen tangible_assets = tang_assets
gen group = .
replace labor_inp= a_120_sueldos_y_salari+a_130_sueldos_y_salari if sap==1
replace labor_inp= admin_sales_costs*0.3 if sap==.

* Exempted vidend income
cap drop quantile
xtile quantile=total_income, n(10)

gen share_div=67 		if quantile==1
replace share_div=87  	if quantile==2
replace share_div=80 	if quantile==3
replace share_div=86 	if quantile==4
replace share_div=90 	if quantile==5
replace share_div=96 	if quantile==6
replace share_div=96 	if quantile==7
replace share_div=92 	if quantile==8
replace share_div=95 	if quantile==9
replace share_div=96 	if quantile==10

replace share_div=share_div/100
gen share_div_data=dividend_exempt/dividend_income*100

replace dividend_exempt=dividend_income*share_div if dividend_exempt==. & dividend_income>0 & exempt_income>0
replace dividend_exempt=0 if exempt_income==0
replace dividend_exempt=0 if dividend_income==0
replace dividend_exempt=. if dividend_income==.
replace dividend_exempt=0 if dividend_income!=. & exempt_income==.
replace dividend_exempt=0 if dividend_income!=. & exempt_income==0
replace dividend_exempt=0 if dividend_income!=. & exempt_income<0

 * STR:
gen STR = .
replace STR = 0.1 if total_income <= 52320000 & year>=2015
replace STR = 0.2 if total_income > 52320000  & total_income <= 105241000 & year>=2015
replace STR = 0.3 if total_income > 105241000 & year>=2015 
 
replace STR = 0.1 if total_income <= 52710000 & year <= 2014
replace STR = 0.2 if total_income > 52710000  & total_income <= 106026000 & year <= 2014
replace STR = 0.3 if total_income > 106026000 & year <= 2014

replace STR = 0.1 if total_income <= 53113000 & year==2018
replace STR = 0.2 if total_income > 53113000  & total_income <= 106835000 & year==2018  
replace STR = 0.3 if total_income > 106835000 & year==2018

replace STR = 0.1 if total_income <= 54303000 & year==2019
replace STR = 0.2 if total_income > 54303000  & total_income <= 109228000 & year==2019  
replace STR = 0.3 if total_income > 109228000 & year==2019

// http://www.pgrweb.go.cr/scij/Busqueda/Normativa/Normas/nrm_texto_completo.aspx?param1=NRTC&nValor1=1&nValor2=87331&nValor3=117923&strTipM=TC

replace STR = 0.05 if total_income <= 5143000 & year==2020
replace STR = 0.1 if total_income > 5143000  & total_income <= 7715000 & year==2020  
replace STR = 0.15 if total_income > 7715000  & total_income <= 10286000 & year==2020
replace STR = 0.2 if total_income > 10286000  & total_income <= 109032000 & year==2020  
replace STR = 0.3 if total_income > 109228000 & year==2020

// http://www.pgrweb.go.cr/scij/Busqueda/Normativa/Normas/nrm_texto_completo.aspx?param1=NRTC&nValor1=1&nValor2=89735&nValor3=0&strTipM=TC#:~:text=i)%20Las%20rentas%20de%20hasta,quince%20por%20ciento%20(15%25).

drop country
generate country = "CRI" 

preserve
use "$data/input/Costa Rica/orbis_ids_multinationals.dta", clear
keep if mult_affected==1
tempfile temp
save `temp', replace
restore

merge m:1 tax_ID using `temp'
drop if _merge==2

replace group = ID_GRUPO
ren mult_affected orbis_match
drop _merge ID_GRUPO

replace orbis_match=0 if orbis_match==.

/* SAP data indicator */
replace sap=0 if sap==.

/* Save temp dataset */
save "$data/temp/Costa Rica/CRI_withvars_temp.dta", replace

/* Run Lasso prodcedure */
include "$code/cleaning/CRI_Lasso_Estimates"	

/* Open main data again */
use "$data/temp/Costa Rica/CRI_withvars_temp.dta", clear

/* Merge new estimated wage bill */
merge 1:1 tax_ID year using "$data/input/Costa Rica/CRI_Lasso_Estimates.dta"
drop _merge

replace labor_inp_lasso=. if labor_inp_lasso<0

summ labor_inp_lasso labor_inp if labor_inp_lasso!=.

gen lasso=(labor_inp_lasso!=.)

replace labor_inp=labor_inp_lasso if lasso==1
drop lasso

/* Add franc zone identification variable */
preserve
import excel "$data/input/Costa Rica/Listado_contribuyentes_zona_franca.xlsx", firstrow clear

gen year=year(Fechainicioexoneración)
ren id tax_ID
ren year year_start_sez

sort tax_ID

keep tax_ID year_start_sez
duplicates drop tax_ID, force

tempfile temp
save `temp', replace
restore

cap drop _merge
merge m:1 tax_ID using `temp'
drop if _merge==2
ren _merge sez
order sez, a(ZonaFranca)
gen sez_n=0
replace sez_n=1 if sez==3
drop sez
ren sez_n sez
order sez, a(ZonaFranca)
gen zona_franca=0
replace zona_franca=1 if ZonaFranca=="S"
order zona_franca, a(ZonaFranca)
order year_start_sez, a(sez)

drop ZonaFranca

label var zona_franca 	"Old SEZ ID variable"
label var sez 			"New SEZ ID variable"

cap drop year_start_sez
cap drop quantile
cap drop share_div
cap drop share_div_data

/* Fix foreign ownership variable */
replace foreign_ownership = 0
replace foreign_ownership = 1 if Casasextrajenra == 1
replace foreign_ownership = 1 if orbis_match == 1

gen foreign_ownership2 = 0
replace foreign_ownership2 = 1 if Capital_extranjero == 1
replace foreign_ownership2 = 1 if orbis_match == 1

tab year
tab year if turnover>1
tab year if turnover>1 & Tipo_Identificacion==""

drop if Tipo_Identificacion=="" & foreign_ownership==0

/* Save dataset */
sort tax_ID year, stable

export delimited using "$data/output/Costa Rica/CRI_withvars.csv", replace