*===============================================================================
* File name: 		CIT_ECU.do
* 
* Description:		This do-file creates the dataset ECU_withvars.csv. 
*
* Input:  					
*					$data/input/Ecuador/bal`i'.dta 
*					$data/input/Ecuador/CIIU4_firmsectors.dta
*
* Output:
*					$data/output/Ecuador/ECU_withvars.csv
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

program breakdown_variables
    syntax, year(int)

    ******** SELECT AND CREATE VARIABLES ********
	
    * GROUP 0
        * Indentification variables
    rename anio year
    rename ruc tax_ID
    generate country = "ECU"
    generate entity = "Legal"   

        * Check for duplicates and drop
    duplicates report year tax_ID 

    * GROUP 1: INCOMES
	
        * Turnover and other income 
    egen turnover = rowtotal(vln_eaf_tdc__6001 vln_eaf_tce__6003 pre_loc_ser_grav_tar_12__6005 pre_loc_ser_grav_tar_0__6007 exportaciones_netas__6009 expor_netas_servi__6011 ing_pre_ser_con__6013 ing_com_sim__6015 ing_por_arr_ope__6017), missing
    egen other_income = rowtotal(ing_reg_ces_res__6019 ing_reg_ces_no_res__6021 div_percibidos_locales__6023 div_pro_soc_no_res__6025 gan_net_med_act_bio_vrz__6027 gan_net_med_pin_vrz__6029 gan_net_med_ifi_vrz__6031 gan_net_dif_cambio__6033 utilidad_vta_act_fijos__6035 uti_enj_der_rep_cap__6037 ing_dev_sub_gob_otr__6039 gan_net_rev_det_vac__6041 gan_net_rev_det_inv__6043 gan_net_rev_det_vac_vta__6045 gan_net_rev_act_bio__6047 gan_net_rev_ppe__6049 gan_net_rev_act_int__6051 gan_net_rev_pro_inv__6053 gan_net_rev_act_eerm__6055 gan_net_rev_inv_no_cte__6057 gan_net_rev_otr__6059 gan_net_rev_gar__6061 gan_net_rev_des__6063 gan_net_rev_cont_one__6065 gan_net_rev_res_neg__6067 gan_net_rev_rmb_cli__6069 gan_net_rev_lit__6071 gan_net_rev_pas_con__6073 gan_net_rev_pro_otr__6075 gan_net_pas_ben_emp__6077 gan_net_pas_otr_ben_emp__6079 rex_don_apo_rpu__6081 rex_don_apo_otr_locales__6083 rex_don_apo_exterior__6085 ing_rmb_seg_luc_ces__6087 ing_rmb_seg_otr__6089 otr_ing_del_exr__6091 otras_rentas_gravadas__6093 ifi_arr_mer_rel_loc__6095 ifi_arr_mer_rel_ext__6097 ifi_arr_mer_no_rel_loc__6099 ifi_arr_mer_no_rel_ext__6101 ifi_cto_trn_rel_loc__6103 ifi_cto_trn_rel_ter__6105 ifi_cto_trn_no_rel_loc__6107 ifi_cto_trn_no_rel_ext__6109 ifi_int_ifi_rel_loc__6111 ifi_int_ifi_rel_ext__6113 ifi_int_ifi_nrel_loc__6115 ifi_int_ifi_rnel_ext__6117 ifi_idv_ter_rel_loc__6119 ifi_idv_ter_rel_ext__6121 ifi_idv_ter_norel_loc__6123 ifi_idv_ter_norel_ext__6125 ifi_idv_tfi_cob_dif__6127 otr_ing_fin__6129 gmi_anc_met_vpp__6131 otr_ing_no_ope__6133 gnt_de_act_dis__6135), missing
	
        * Exempt income
    egen exempt_income = rowtotal(vex_vln_eaf_tdc__6002 vex_vln_eaf_tce__6004 vex_pre_loc_ser_gra_tr_12_6006 vex_pre_loc_ser_gra_tar_0_6008 vex_exportaciones_netas__6010 vex_expor_netas_servi__6012 vex_ing_pre_ser_con__6014 vex_ing_com_sim__6016 vex_ing_por_arr_ope__6018 vex_ing_reg_ces_res__6020 vex_ing_reg_ces_no_res__6022 vex_div_percibidos_loc__6024 vex_div_pro_soc_no_res__6026 vex_gan_nt_md_act_bio_vrz_6028 vex_gan_net_med_pin_vrz__6030 vex_gan_net_med_ifi_vrz__6032 vex_gan_net_dif_cambio__6034 vex_utilidad_vta_act_fij__6036 vex_uti_enj_der_rep_cap__6038 vex_ing_dev_sub_gob_otr__6040 vex_gan_net_rev_det_vac__6042 vex_gan_net_rev_det_inv__6044 vex_gan_net_rev_dt_vc_vta_6046 vex_gan_net_rev_act_bio__6048 vex_gan_net_rev_ppe__6050 vex_gan_net_rev_act_int__6052 vex_gan_net_rev_pro_inv__6054 vex_gan_net_rev_act_eerm__6056 vex_gan_net_rv_inv_no_cte_6058 vex_gan_net_rev_otr__6060 vex_gan_net_rev_gar__6062 vex_gan_net_rev_des__6064 vex_gan_net_rev_cont_one__6066 vex_gan_net_rev_res_neg__6068 vex_gan_net_rev_rmb_cli__6070 vex_gan_net_rev_lit__6072 vex_gan_net_rev_pas_con__6074 vex_gan_net_rev_pro_otr__6076 vex_gan_net_pas_ben_emp__6078 vex_gan_net_ps_otr_bn_emp_6080 vex_rex_don_apo_rpu__6082 vex_rex_don_apo_otr_loc__6084 vex_rex_don_apo_exterior__6086 vex_ing_rmb_seg_luc_ces__6088 vex_ing_rmb_seg_otr__6090 vex_otr_ing_del_exr__6092 otras_rentas_exentas__6094 vex_ifi_arr_mer_rel_loc__6096 vex_ifi_arr_mer_rel_ext__6098 vex_ifi_arr_mer_no_rl_lc__6100 vex_ifi_arr_mer_no_rl_ext_6102 vex_ifi_cto_trn_rel_loc__6104 vex_ifi_cto_trn_rel_ter__6106 vex_ifi_cto_trn_no_rl_loc_6108 vex_ifi_cto_trn_no_rl_ext_6110 vex_ifi_int_ifi_rel_loc__6112 vex_ifi_int_ifi_rel_ext__6114 vex_ifi_int_ifi_nrel_loc__6116 vex_ifi_int_ifi_nrel_ext__6118 vex_ifi_idv_ter_rel_loc__6120 vex_ifi_idv_ter_rel_ext__6122 v30_ifi_idv_ter_norel_loc_6124 vex_ifi_idv_ter_norel_ext_6126 vex_ifi_idv_tfi_cob_dif__6128 vex_otr_ing_fin__6130 vex_gmi_anc_met_vpp__6132 vex_otr_ing_no_ope__6134 vex_gnt_de_act_dis__6136), missing
	
	* Dividend income
	egen dividend_income=rowtotal(div_percibidos_locales__6023 div_pro_soc_no_res__6025), missing 
	egen dividend_exempt=rowtotal(vex_div_percibidos_loc__6024 vex_div_pro_soc_no_res__6026), missing
	
        * Total income (turnover + other_income)
    gen total_income = total_ingresos__6999
    egen total_income_built = rowtotal(turnover other_income), missing
        * Taxable income (-exempt income)
    gen taxable_income = total_income - cond(missing(exempt_income), 0, exempt_income)

 foreach var of varlist costo_ssa_qcm__7040-vnd_gto_pnt_act_dis__7315 {
   local newname = substr("`var'", -4, 4)
   rename `var' v_`newname'
   }

    * GROUP 2: COST ITEMS
	
        * Cost of good sold 
gen cogs = .
        * Material Inputs
    egen material_inp = rowtotal(cto_ivi_bienes_npp__7001 cto_cln_bienes_npp__7004 cto_ipr_bienes_npp__7007 gto_ipr_bienes_npp__7008 cto_ivi_materia_prima__7013 cto_cln_materia_prima__7016 cto_ipr_materia_prima__7019 costo_ivi_ppr__7025 costo_ivi_pte__7031), missing
	    * Labor Inputs
    egen labor_inp = rowtotal(v_7040-v_7063), missing
	
		* Selling, admin and other operating costs
		if year == 2014 {
	egen operating_inp = rowtotal(v_7142-v_7147  ///
							v_7152-v_7162	///
							v_7173-v_7201 ///
							v_7212-v_7222 ///
							v_7235-v_7237), missing
		} 
		else {
		    egen operating_inp = rowtotal(v_7142-v_7147  ///
							v_7152-v_7162	///
							v_7173-v_7201 ///
							v_7211-v_7222 ///
							v_7235-v_7237), missing
		}
		
        * Capital Inputs 
    egen capital_inp = rowtotal(v_7166-v_7171), missing
   
        * Financial Inputs
    egen financial_inp = rowtotal(v_7149 v_7150 v_7202-v_7204 ///
								  v_7251-v_7312 v_7245 v_7246), missing
	
        * Depreciation 
	 foreach var of varlist v_7064-v_7141 {
		replace `var' = abs(`var') 
		}
    
	egen depreciation = rowtotal(v_7064-v_7141), missing
	egen acc_depreciation = rowtotal(v_7064 v_7065 v_7066), missing
	
        * Other Inputs
		 foreach var of varlist v_7163-v_7165 v_7210 v_7234 v_7238-v_7243  v_7247-v_7249 {
		replace `var' = abs(`var') 
		}
    egen other_inp = rowtotal(v_7163-v_7165 ///
								v_7205-v_7210 v_7223-v_7234 ///
								v_7238-v_7243 v_7247-v_7249 ///
								v_7314 v_7315 ), missing
    
   
        * Non deductible Inputs
		foreach var of varlist gto_no_deducibles_loc__806  gto_no_deducibles_exr__807 gto_generar_ing_exentos__808 ptb_atr_ing_exentos__809 aju_precios_transferencia_811 cyg_dig_sir__813 {
		replace `var' = abs(`var') 
		}
    egen non_deduc_inp = rowtotal(gto_no_deducibles_loc__806  gto_no_deducibles_exr__807 gto_generar_ing_exentos__808 ptb_atr_ing_exentos__809 aju_precios_transferencia_811 cyg_dig_sir__813), missing

        * Total costs: add up all costs & expenditure
    egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing
    gen tot_cost_dataset = abs(totas_costos_gastos__7999)
    gen tot_cost = tot_cost_dataset
	
        * Deductible Costs: total costs - non-deductible inputs 
    gen deductible_cost = tot_cost - cond(missing(non_deduc_inp), 0, non_deduc_inp)

    * GROUP 3: PROFITS
	    * Gross profit
	gen gross_profit = .

        * Net profit
    gen net_profit = total_income - cond(missing(tot_cost), 0, tot_cost)
    gen net_profit_built = total_income - tot_cost

        * Taxable profit
    gen taxable_profit = utilidad_ejercicio__801
    replace taxable_profit = -perdida_ejercicio__802 if taxable_profit == 0
    gen taxable_profit_built = taxable_income - cond(missing(deductible_cost), 0, deductible_cost) // after all adjustment

    * GROUP 4: GROSS & NET TAX BASE
	
        * Investment Incentives  (From tax base)
    gen investment_taxbase = .
        * Capital allowances  (From tax base)
	gen capital_allowance = .
        * Losses (always from tax base)
    gen loss_carryforward = abs(amo_ptr_anios_anteriores__833)
        * Other Deductions (always from tax base)
    gen other_ded_taxbase = abs(deducciones_adicionales__810)
        * Add up credits & deductions from tax base: 
    egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

        * Gross tax base (taxable_profit - tot_deduc_taxbase)
    gen gross_tax_base_built = taxable_profit - tot_deduc_taxbase
    gen gross_tax_base = utilidad_gravable__836 + loss_carryforward - capital_allowance

        * Net tax base (gross_tax_base - loss_carryforward)
    gen net_tax_base = utilidad_gravable__836 
	replace net_tax_base = (-1)*perdida__837 if utilidad_gravable__836 == 0
	
    * GROUP 5: GROSS & NET TAX LIABILITY
	
        * Gross tax liability
    gen gross_tax_liability = impuesto_renta_causado__850

        * Credits for foreign taxes paid
		if year !=2019{
    gen cred_foreign_tax = cre_tri_isd_eje_decla__862  
	} 
	else {
	gen cred_foreign_tax =	cre_tri_isd_eje_ant__863
	}
        * Investment credits from tax liability
    gen investment_taxliab = abs(exo_y_ctr_leyes_epc__864)
		* Special firms credits from tax liability
	gen special_taxliab = .
	* International Trade credits 
	gen trade_taxliab = .
        * Other credit and allowances from tax liability
    gen other_cred_taxliab = .
 *Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing

    * Net tax liability (gross_tax_liability - tot_deduc_taxliab)
    gen net_tax_liability = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)
	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

    * GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
	
        * Add up partial/advance payments
    egen partial_advanced_pay = rowtotal(ati_ire_pag_epu__860 ant_red_corr_eje_decl__853), missing
        * Add withholding 
    egen withholding = rowtotal(ret_fuente_eje_fiscal__857 ret_div_anticipados__858 ret_ing_exr_cdc__859), missing
        * Other creditable tax payments
    egen other_cred_tax_pay = rowtotal(ctr_anios_anteriores__861 cre_tri_isd_eje_ant__863 impuesto_renta_unico__867 saldo_atc_pendiente_pago__856), missing
    replace other_cred_tax_pay = other_cred_tax_pay-ctr_pll_ire_unico__868 if !missing(ctr_pll_ire_unico__868)

        * Tax to remit
    gen tax_to_remit =  impuesto_renta_pagar__869 
    replace tax_to_remit = -saldo_favor_contribuyente_870 if tax_to_remit == 0

    **** Treatment of missings and 0
    foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
        replace `var' = 0 if missing(`var') & !missing(total_income)
    }

    ********* Add labels and drop some variables ********
    label variable tax_ID "Tax ID"
    label variable year "Fiscal Year"
    label variable turnover "Turnover"
    label variable total_income "Total income"
    label variable taxable_income "Taxable income"
    label variable tot_cost "Total Costs"
    label variable deductible_cost "Deductible Costs"
    label variable net_profit "Net profit"
    label variable taxable_income "Taxable profit"
    label variable gross_tax_base "Gross Tax Base"
    label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
    label variable net_tax_base "Net Tax Base"
    label variable gross_tax_liability "Gross Tax Liability"
    label variable net_tax_liability "Net Tax Liability"
    label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
    label variable tax_to_remit "Tax to Remit"
    label variable country "Country"
	
	  * Adjustement
replace total_income = turnover if total_income==.	
replace total_income = turnover if total_income<turnover 	

tostring  sp_ex_apl_reg_pre_tra_30 , replace
tostring cumple_deber_inf_com_soc__838, replace
tostring fin_luc_adm_ope_zede__841, replace 
end


* Load data, clean and append together
forvalues i=2014/2019{
    di in red "YEAR: `i'"
    import delimited "$data/input/Ecuador/bal`i'.txt", ///
    delimiter(tab) varnames(1) encoding(utf16) clear
   
    * Program clean variables
    breakdown_variables, year(`i')
    
	*Save data
    save "$data/temp/Ecuador/temp_`i'.dta", replace
}
clear

forvalues i=2014/2019{
	    di in red "YEAR: `i'"
    append using "$data/temp/Ecuador/temp_`i'.dta"
}


* GROUP 7: FIRM CHARACTERISTICS

gen total_assets = total_activo__499 	

gen foreign_ownership = .
replace foreign_ownership = 1 if porcion_comp_soc_no_inf__839 >= 10 |  porcion_comp_soc_si_inf__840 >= 10

gen capital_city = .

* GROUP 8: STATUTORY TAX RATE

gen STR = .
replace STR = 0.25 if year >= 2018
replace  STR = 0.28 if year >= 2018 & (porcion_comp_soc_si_inf__840>= 50 | porcion_comp_soc_no_inf__839>=50)
replace  STR = 0.22 if year >= 2018 & turnover <=1000000
replace  STR = 0.22 if year >= 2013 & year <= 2017

/* SEZ identifier */
gen sez=(fin_luc_adm_ope_zede__841=="SI")

    ************* KEEP VARIABLES WE NEED *************
        * Create locals to keep variables
    local group0 year country tax_ID entity  ciiu  descripcion_rama
    local group1 turnover exempt_income other_income total_income taxable_income dividend_income dividend_exempt
    local group2 tot_cost *_inp deductible_cost depreciation acc_depreciation cogs
    local group3 taxable_profit net_profit gross_profit
    local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase
    local group5 gross_tax_liability net_tax_liability tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
    local group6 withholding partial_advanced_pay other_cred_tax_pay tax_to_remit nombre ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab 
	local group7 total_assets foreign_ownership porcion_comp_soc_no_inf__839 porcion_comp_soc_si_inf__840 capital_city STR sez
	
	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7' 

sort tax_ID year, stable

* Sectors
    g section = substr(ciiu,1,1)
    g descr_section = descripcion_rama
    g code = substr(subinstr(ciiu,".","",.),2,.)
	
preserve
use "$data/input/Ecuador/CIIU4_firmsectors.dta", clear
keep section descr_section 
duplicates drop section, force
tempfile sector
save `sector'
restore

merge m:1 section using `sector'
drop if _merge == 2
drop _merge 
   
************* Save *************
sort tax_ID year, stable
export delimited "$data/output/Ecuador/ECU_withvars.csv", replace