#===============================================================================
# File name: 		  CIT_GRC.do
# 
# Description:		This do-file creates the dataset GRC_withvars.csv. 
#
# Input:  					
#					        $data/input/Greece/taxreturns_noduplicates_jan2021.csv 
#					        $data/input/Greece/GRC_Subs_Scope_GUO.csv 
#					        $data/input/Greece/GRC_export_econ_var_2018.xlsx 
#					        $data/input/Greece/legal status code description.xlsx
#					        $data/input/Greece/GRC_Lasso_Estimates.csv
#
# Output:
#					        $data/output/Greece/GRC_withvars.csv
#===============================================================================
  

#### | 1. PREAMBLE | ####

#########################################################################

# + package and paths: 
#..........................

# define a list of required packages
packages <- c("tidyverse", "data.table", "lubridate", "collapse" , "readxl", "lazyeval", "sjlabelled", "readstata13")

# loop through the list of packages and check if they are installed and loaded
for (p in packages) {
  if (!require(p, character.only = TRUE)) {
    install.packages(p)
    library(p, character.only = TRUE)
  }
}

cd <- c("C:/Users/Greece")

data <- c(paste0(cd, "/data/input/Greece"))
output <- c(paste0(cd, "/data/output/Greece"))

# + Load files: 
#..........................
setwd(rawdata)

CIT <- fread("taxreturns_noduplicates_jan2021.csv")

# Merge ORBIS DATA on raw data: 
length(unique(CIT$taxid[!is.na(CIT$taxid)])) #97,586
length(CIT$taxid) #2,000,545
length(CIT$taxid[!is.na(CIT$taxid)]) #1,464,485

length(unique(CIT$firmcode)) #181,788

# We can get back some taxid variable from the firmcode:
CIT <- CIT %>% 
  group_by(firmcode) %>%
  mutate(vat_id = taxid) %>% 
  fill(vat_id, .direction = "downup") %>% 
  relocate(firmcode, taxid, vat_id) %>% ungroup()
#
length(CIT$vat_id) #2,000,545
length(CIT$vat_id[!is.na(CIT$vat_id)]) #1,532,189
#
##Focus on 2018 for example
length(CIT$vat_id[!is.na(CIT$vat_id) & CIT$fin_year == 2018]) #92,617
length(CIT$firmcode[!is.na(CIT$firmcode) & CIT$fin_year == 2018]) #125,240

gc()

#### ORBIS: 

df.orbis <- read.csv(paste0(orbis, "/GRC_Subs_Scope_GUO.csv")) %>%   
  mutate(vat_id = as.integer(VAT_NUMBER),
         lei = as.integer(LEI)) %>%
  unique() %>% 
  filter(!is.na(vat_id))


df.orbis.vat <- df.orbis %>% distinct(vat_id, .keep_all = TRUE)


# -- MERGE

df.orbis.tin <- df.orbis %>% distinct(TIN, .keep_all = TRUE)
df.orbis.tin <- df.orbis.tin %>% 
  mutate(tax_id = if_else(is.na(TIN), vat_id, TIN))

length(unique(df.orbis.tin$tax_id)) # 1073

merge.i <- inner_join(CIT, df.orbis.tin, by  = c("vat_id" = "tax_id"))  %>%  # merge == 3 : 15,904
  select(BVD_ID_NUMBER, NAME) %>% unique()
length(unique(merge.i$BVD_ID_NUMBER)) # 957

## -----------Learn more about those that did not match:
merge.anti <- anti_join(df.orbis.tin, CIT, by  = c("tax_id" = "vat_id"))   # 116

## Match back with information for 2018 on those orbis firms
## numbers are in thousand dollar
GRC_export_econ_var_2018 <- read_excel("GRC_export_econ_var_2018.xlsx", sheet = "Results") %>% 
  mutate(tangible_assets_2018  = as.numeric(TFAS)*11810*1000, ## official exchange rate, need to get to EUR
        labor_inp_2018 =  as.numeric(STAF)*1.1810*1000,
        fin_year = 2018) %>% 
  select(BVD_ID_NUMBER, labor_inp_2018, tangible_assets_2018, fin_year)

merged <- left_join(CIT, df.orbis.tin, by = c("vat_id" = "tax_id"))

# Match orbis info
merged <- left_join(merged, GRC_export_econ_var_2018, by = c("fin_year", "BVD_ID_NUMBER"))

CIT <- merged %>% 
  mutate(orbis_match = if_else(!is.na(ORBISID), 1, 0))

temp <- CIT %>% group_by(GUO_BVD_ID_NUMBER, fin_year) %>% mutate(n = n()) %>% filter(orbis_match ==1)


# #############################################################################
# ############################ LEGAL ENTITIES #################################
# #############################################################################

df <- CIT %>% filter(liquid != 1) # some are not noted

# Legal Status
df <- df %>% rename(legal_status = formcode)
status_code <- read_excel("legal status code description.xlsx") %>% select(code, description)
df <- left_join(df, status_code, by =join_by(legal_status == code))

test <- df %>% group_by(legal_status, description) %>% summarise(count = n()) 
# Will remove some cases like non-profit organization

# ######## SELECT AND CREATE VARIABLES ########
# # GROUP 0

df <- df %>% mutate(year = fin_year)

df <- df %>% mutate( tax_ID = firmcode)
  
df <- df %>% mutate(country = "GRC")

df <- df %>% mutate(entity = "Legal")

# We exclude some entities from our sample and keep the following:
df <- df %>% filter(legal_status %in% c(4, 5, 7, 8, 9, 35, 51, 57, 58, 87, 89, NA_real_))
# 4 limited liability company
# 5 single member  limited liability company
# 7 société anonyme
# 8 shipping company
# 9 special shipping company
# 35 shipping company of special purpose
# 51 single member SA
# 57 private capital company
# 58 single member private capital company
# 87 foreign company of real estate property
# 89 branch of foreign company

# # GROUP 1: INCOMES

	# Turnover and other income 

df <- df %>% mutate(turnover =  poso_015,
turnover = if_else(poso_015 < 0, 0, turnover),
turnover = if_else(poso_015==0 & sales>0 & !is.na(sales), sales, turnover)) ## not sure yet
  

# Exempt and Other income 
summary(df$poso_026) 
summary(df$poso_028)
summary(df$poso_460)
summary(df$poso_462)

df <- df %>% mutate(poso_026 = if_else( poso_026 < 0, NA_real_, poso_026),
poso_028 = if_else( poso_028 < 0, NA_real_, poso_028),
poso_460 = if_else( poso_460 < 0, NA_real_, poso_460),
poso_462 = if_else( poso_462 < 0, NA_real_, poso_462),
poso_098 = if_else( poso_098 < 0, NA_real_, poso_098),

other_income = rowSums(select(., "poso_026", "poso_028", "poso_460"), na.rm = T),
exempt_income = rowSums(select(., "poso_026", "poso_028", "poso_460", "poso_462"), na.rm = T),

dividend_income = rowSums(select(., "poso_026"), na.rm = T),
dividend_exempt = rowSums(select(., "poso_098"), na.rm = T))


# Total income (turnover + other_income)
df <- df %>% mutate(total_income = rowSums(select(., turnover, other_income), na.rm = T))

# Taxable income (-exempt income)
df <- df %>% 
  mutate(taxable_income = total_income - ifelse(is.na(exempt_income), 0, exempt_income))

# GROUP 2: COST ITEMS

	# Cost of Goods Sold
summary(df$grossprofit)

df <- df %>% 
  mutate(cogs = turnover - grossprofit )

summary(df$cogs)

	# Labor Inputs (only for firms distributing)
summary(df$poso_032)
summary(df$poso_033)
summary(df$poso_430)

df <- df %>% 
  mutate(labor_inp = rowSums(select(., poso_032, poso_033), na.rm =T))

summary(df$labor_inp)

df <- df %>% 
  mutate(labor_inp = if_else(orbis_match == 1 & labor_inp ==0 & !is.na(labor_inp_2018), labor_inp_2018, labor_inp))

	# Material Inputs
 df <- df %>% 
   mutate( material_inp = NA_real_, 
	#Selling, admin and other operating costs
   operating_inp = NA_real_, 
	# Capital Inputs
	capital_inp = NA_real_, 
	# Financial Inputs
	financial_inp = NA_real_, 
	# Depreciation 
	depreciations = if_else(depreciations<0, 0, depreciations),
	accum_deprec = if_else(accum_deprec<0, 0, accum_deprec),
	depreciation = depreciations, 
	# Accelerated depreciation
	acc_depreciation = NA_real_,
	# Other Inputs
	other_inp = NA_real_,
	# Non deductible Inputs
	poso_018 = if_else(poso_018<0, 0, poso_018),
	poso_019 = if_else(poso_019<0, 0, poso_019),
	poso_029 = if_else(poso_029<0, 0, poso_029),
	poso_022 = if_else(poso_022<0, 0, poso_022),
	poso_023 = if_else(poso_023<0, 0, poso_023),
	
  non_deduc_inp = rowSums(select(., poso_018, poso_019, poso_029, poso_022, poso_023), na.rm =T))


df %>% filter(!is.na(poso_016) & !is.na(poso_017) & !is.na(poso_116) & !is.na(poso_117)) %>% 
  select(poso_016, poso_017, poso_116, poso_117) %>% head(., n = 20)

t <- df %>% filter(!is.na(poso_016) & !is.na(poso_017) & !is.na(poso_116) & !is.na(poso_117)) %>% 
  select(poso_016, poso_017, poso_116, poso_117, year) %>% filter(poso_016< 0
)

  # Gross profit
df <- df %>% mutate(gross_profit = grossprofit)
  
  # with poso_016 and poso_017
df <- df %>% mutate(net_profit_0 = poso_016, 
net_profit_0 = if_else(poso_016 == 0 & poso_017 > 0, -1*poso_017, net_profit_0),
net_profit_0 = if_else(poso_016 == 0 & poso_017 < 0 , poso_017, net_profit_0),
net_profit_0 = if_else(poso_016 < 0 & poso_017 == 0, -1*poso_016, net_profit_0),
# with poso_116 and poso_117
net_profit_1 = poso_116, 
net_profit_1 = if_else(poso_116 == 0 & poso_117 > 0, -1*poso_117, net_profit_1),
net_profit_1 = if_else(poso_116 == 0 & poso_117 < 0 , poso_117, net_profit_1),
net_profit_1 = if_else(poso_116 < 0 & poso_117 == 0, -1*poso_116, net_profit_1))

summary(df$net_profit_0)
summary(df$net_profit_1)

# Net profit constructed with 16 and 17 has better coverage. When they differ, decide what to do
df <- df %>% mutate(net_profit = if_else(net_profit_0 == 0 & net_profit_1!=0, net_profit_1, net_profit_0))

df <- df %>% mutate(explicit_costs = if_else(poso_016 != 0, turnover - poso_016, poso_015 + poso_017),
tot_cost = explicit_costs,
tot_cost = if_else(turnover == 0 & tot_cost<0, abs(tot_cost), tot_cost),
tot_cost = if_else(turnover != 0 & tot_cost<0, 0, tot_cost))

	# Deductible Costs: total costs - non-deductible inputs 
df <- df %>% mutate(deductible_cost = if_else(!is.na(non_deduc_inp), tot_cost - non_deduc_inp, tot_cost),
deductible_cost = if_else(deductible_cost<0, 0, deductible_cost))  

	# Taxable profit
df <- df %>% mutate(taxable_profit = taxable_income - deductible_cost)

summary(df$deductible_cost)
summary(df$taxable_profit)
summary(df$net_profit)

# GROUP 4: GROSS & NET TAX BASE
  
  # Investment Incentives  (From tax base)
df <- df %>% mutate(
   investment_taxbase = NA_real_,
# Capital allowances  (From tax base)
   capital_allowance = NA_real_,
# Losses (always from tax base)
   loss_carryforward = if_else(poso_039<0, abs(poso_039), poso_039),
# Other Deductions (always from tax base)
   other_ded_taxbase = NA_real_,
# Add up credits & deductions from tax base: 
   tot_deduc_taxbase = 0)

# Gross tax base (taxable_profit - tot_deduc_taxbase)
df <- df %>% mutate(gross_tax_base_built = taxable_profit - tot_deduc_taxbase,
gross_tax_base = poso_038)

# Net tax base (gross_tax_base - loss_carryforward)
df <- df %>% mutate(net_tax_base_built = gross_tax_base - loss_carryforward)

df <- df %>% mutate(poso_003 = if_else(poso_003<0, abs(poso_003), poso_003),
net_tax_base = if_else(poso_001==0, -poso_003, poso_001),
net_tax_base = if_else(is.na(poso_001), NA_real_, net_tax_base))

t <- df %>% 
  select(net_tax_base, net_tax_base_built, total_income, turnover, net_profit, taxable_income, poso_001, poso_003, poso_048, poso_448, turnover, taxable_income, total_income) %>% 
  mutate(flag = if_else(net_tax_base!=net_tax_base_built, 1, 0)) %>%  filter(!is.na(net_tax_base))

table(t$flag)
  
  # Gross tax liability (net tax base#CIT rate)
df <- df %>% mutate(gross_tax_liability = poso_004,
CIT_rate = if_else(net_tax_base != 0, poso_004/net_tax_base, 0),
CIT_rate = if_else(is.na(poso_004) | is.na(net_tax_base), NA_real_, CIT_rate))

df <- df %>% mutate(tax_owed_property = poso_005)    
summary(df$poso_005)

#-------------<   
df <- df %>% mutate(
  poso_004 = if_else(is.na(poso_004), 0,  poso_004),
  poso_005 = if_else(is.na(poso_005), 0,  poso_005),
  poso_579 = if_else(is.na(poso_579), 0,  poso_579),
  poso_700 = if_else(is.na(poso_700), 0,  poso_700))
summary(df$poso_579)
summary(df$poso_700)

  # Credits for foreign taxes paid
df <- df %>% mutate(
   cred_foreign_tax = NA_real_,
# Investment credits from tax liability
   investment_taxliab = poso_579,
# Special firms credits from tax liability
   special_taxliab = NA_real_,
# International Trade credits 
   trade_taxliab = NA_real_,
# Other credit and allowances from tax liability

  other_cred_taxliab = ((poso_004 + poso_005) - poso_579 - poso_700),
  other_cred_taxliab = if_else(other_cred_taxliab <0, 0, other_cred_taxliab))

summary(df$other_cred_taxliab)

	# Add up credits & deductions from tax liability 
df <- df %>% mutate(tot_deduc_taxliab = rowSums(select(.,cred_foreign_tax,
               investment_taxliab,
               special_taxliab,
               trade_taxliab,
               other_cred_taxliab), na.rm = T),
	# Add up credits & deductions that are not necessarily real credits from tax liability 
                   tot_noelse_taxliab = rowSums(select(., cred_foreign_tax,  
               other_cred_taxliab), na.rm = T),
	
	            tot_deduc_taxliab_bis = poso_700-poso_005-poso_004 )

	# Net tax liability (gross_tax_liability - tot_deduc_taxliab)

df <- df %>%
  mutate(net_tax_liability = gross_tax_liability - tot_deduc_taxliab,
         ntl_bis = poso_700-poso_005,
        # Net tax liability without foreign and other credits  
         ntl_noelse = net_tax_liability + tot_noelse_taxliab)

# GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
  
df <- df %>% mutate(poso_009 = if_else(is.na(poso_009), 0,  poso_009), 
poso_008 = if_else(is.na(poso_008), 0,  poso_008),
poso_008 = if_else(poso_008<0, 0,  poso_008),
poso_600 = if_else(is.na(poso_600), 0,  poso_600), 
poso_701 = if_else(is.na(poso_701), 0,  poso_701),
poso_701 = if_else(poso_701<0, 0,  poso_701),
poso_702 = if_else(is.na(poso_702), 0,  poso_702),
poso_702 = if_else(poso_702<0, 0,  poso_702),

# Add up partial/advance payments
partial_advanced_pay = poso_008,

# Add withholding 
withholding = poso_009,

# Other creditable tax payments
other_cred_tax_pay = (poso_701 - poso_009 - poso_008) + poso_702,
other_cred_tax_pay = if_else(other_cred_tax_pay<0, 0, other_cred_tax_pay)

)

summary(df$poso_701)
summary(df$poso_009)
summary(df$poso_008)
summary(df$poso_702)
summary(df$other_cred_tax_pay)


# Tax to remit
df <- df %>% mutate( tax_to_remit  = net_tax_liability - partial_advanced_pay - other_cred_tax_pay)

#### Treatment of missings and 0
varlist <- c("gross_tax_base", "net_tax_base", "gross_tax_liability", "net_tax_liability")
df <- df %>%
  mutate(across(all_of(varlist), ~if_else(is.na(.) & !is.na(total_income), 0, .)))

# Move tax liability deductions up before gross tax base level
df <- df %>% mutate(abs_deduc_taxbase = tot_deduc_taxliab*(1/CIT_rate),
abs_deduc_taxbase = if_else(is.na(abs_deduc_taxbase), 0, abs_deduc_taxbase),
 abs_gross_tax_base = gross_tax_base - abs_deduc_taxbase,
 abs_net_tax_base = net_tax_base - abs_deduc_taxbase,
 abs_tax_liability = abs_net_tax_base*CIT_rate) ## // should equal net_tax_liability, check this


########### NET OF LOSSES (NOL) TAX BASE & TAX LIABILITY  ######################
# Reintegrate losses carry forward to have the theoretical tax liability for the period.

df <- df %>% mutate( nol_tax_base = abs_net_tax_base + loss_carryforward,
losses_tax_liab = loss_carryforward*CIT_rate,
 nol_tax_liability = abs_tax_liability + losses_tax_liab)

################# SECTORS: #########################

df <- df %>%
  mutate(sector = case_when(
    kad <= 30000 ~ 1,
    (kad >= 30001 & kad <= 70000) ~ 2,
    (kad >= 70001 & kad <= 999999) ~ 3,
    (kad >= 1000000 & kad <= 1999999) ~ 4,
    (kad >= 2000000 & kad <= 2999999) ~ 5,
    (kad >= 3000000 & kad <= 3999999) ~ 6,
    (kad >= 4000000 & kad <= 4999999) ~ 7,
    (kad >= 5000000 & kad <= 5999999) ~ 8,
    (kad >= 6000000 & kad <= 6999999) ~ 9,
    (kad >= 7000000 & kad <= 7999999) ~ 10,
    (kad >= 8000000 & kad <= 8999999) ~ 11,
    (kad >= 9000000 & kad <= 9999999) ~ 12,
    (kad >= 10000000 & kad <= 10999999) ~ 13,
    (kad >= 11000000 & kad <= 11999999) ~ 14,
    (kad >= 12000000 & kad <= 12999999) ~ 15,
    (kad >= 13000000 & kad <= 13999999) ~ 16,
    (kad >= 14000000 & kad <= 14999999) ~ 17,
    (kad >= 15000000 & kad <= 15999999) ~ 18,
    (kad >= 16000000 & kad <= 16999999) ~ 19,
    (kad >= 17000000 & kad <= 17999999) ~ 20,
    (kad >= 18000000 & kad <= 18999999) ~ 21,
    (kad >= 19000000 & kad <= 19999999) ~ 22,
    (kad >= 20000000 & kad <= 20999999) ~ 23,
    (kad >= 21000000 & kad <= 21999999) ~ 24,
    (kad >= 22000000 & kad <= 22999999) ~ 25,
    (kad >= 23000000 & kad <= 23999999) ~ 26,
    (kad >= 24000000 & kad <= 24999999) ~ 27,
    (kad >= 25000000 & kad <= 25999999) ~ 28,
    (kad >= 26000000 & kad <= 26999999) ~ 29,
    (kad >= 27000000 & kad <= 27999999) ~ 30,
    (kad >= 28000000 & kad <= 28999999) ~ 31,
    (kad >= 29000000 & kad <= 29999999) ~ 32,
    (kad >= 30000000 & kad <= 30999999) ~ 33,
    (kad >= 31000000 & kad <= 31999999) ~ 34,
    (kad >= 32000000 & kad <= 32999999) ~ 35,
    (kad >= 33000000 & kad <= 33999999) ~ 36,
    (kad >= 34000000 & kad <= 34999999) ~ 37,
    (kad >= 35000000 & kad <= 35999999) ~ 38,
    (kad >= 36000000 & kad <= 36999999) ~ 39,
    (kad >= 37000000 & kad <= 37999999) ~ 40,
    (kad >= 38000000 & kad <= 38999999) ~ 41,
    (kad >= 39000000 & kad <= 39999999) ~ 42,
    (kad >= 40000000 & kad <= 40999999) ~ 43,
    (kad >= 41000000 & kad <= 41999999) ~ 44,
    (kad >= 42000000 & kad <= 42999999) ~ 45,
    (kad >= 43000000 & kad <= 43999999) ~ 46,
    (kad >= 44000000 & kad <= 44999999) ~ 47,
    (kad >= 45000000 & kad <= 45999999) ~ 48,
    (kad >= 46000000 & kad <= 46999999) ~ 49,
    (kad >= 47000000 & kad <= 47999999) ~ 50,
    (kad >= 48000000 & kad <= 48999999) ~ 51,
    (kad >= 49000000 & kad <= 49999999) ~ 52,
    (kad >= 50000000 & kad <= 50999999) ~ 53,
    (kad >= 51000000 & kad <= 51999999) ~ 54,
    (kad >= 52000000 & kad <= 52999999) ~ 55,
    (kad >= 53000000 & kad <= 53999999) ~ 56,
    (kad >= 54000000 & kad <= 54999999) ~ 57,
    (kad >= 55000000 & kad <= 55999999) ~ 58,
    (kad >= 56000000 & kad <= 56999999) ~ 59,
    (kad >= 57000000 & kad <= 57999999) ~ 60,
    (kad >= 58000000 & kad <= 58999999) ~ 61,
    (kad >= 59000000 & kad <= 59999999) ~ 62,
    (kad >= 60000000 & kad <= 60999999) ~ 63,
    (kad >= 61000000 & kad <= 61999999) ~ 64,
    (kad >= 62000000 & kad <= 62999999) ~ 65,
    (kad >= 63000000 & kad <= 63999999) ~ 66,
    (kad >= 64000000 & kad <= 64999999) ~ 67,
    (kad >= 65000000 & kad <= 65999999) ~ 68,
    (kad >= 66000000 & kad <= 66999999) ~ 69,
    (kad >= 67000000 & kad <= 67999999) ~ 70,
    (kad >= 68000000 & kad <= 68999999) ~ 71,
    (kad >= 69000000 & kad <= 69999999) ~ 72,
    (kad >= 70000000 & kad <= 70999999) ~ 73,
    (kad >= 71000000 & kad <= 71999999) ~ 74,
    (kad >= 72000000 & kad <= 72999999) ~ 75,
    (kad >= 73000000 & kad <= 73999999) ~ 76,
    (kad >= 74000000 & kad <= 74999999) ~ 77,
    (kad >= 75000000 & kad <= 75999999) ~ 78,
    (kad >= 76000000 & kad <= 76999999) ~ 79,
    (kad >= 77000000 & kad <= 77999999) ~ 80,
    (kad >= 78000000 & kad <= 78999999) ~ 81,
    (kad >= 79000000 & kad <= 79999999) ~ 82,
    (kad >= 80000000 & kad <= 80999999) ~ 83,
    (kad >= 81000000 & kad <= 81999999) ~ 84,
    (kad >= 82000000 & kad <= 82999999) ~ 85,
    (kad >= 83000000 & kad <= 83999999) ~ 86,
    (kad >= 84000000 & kad <= 84999999) ~ 87,
    (kad >= 85000000 & kad <= 85999999) ~ 88,
    (kad >= 86000000 & kad <= 86999999) ~ 89,
    (kad >= 87000000 & kad <= 87999999) ~ 90,
    (kad >= 88000000 & kad <= 88999999) ~ 91,
    (kad >= 89000000 & kad <= 89999999) ~ 92,
    (kad >= 90000000 & kad <= 90999999) ~ 93,
    (kad >= 91000000 & kad <= 91999999) ~ 94,
    (kad >= 92000000 & kad <= 92999999) ~ 95,
    (kad >= 93000000 & kad <= 93999999) ~ 96,
    (kad >= 94000000 & kad <= 94999999) ~ 97,
    (kad >= 95000000 & kad <= 95999999) ~ 98,
    (kad >= 96000000 & kad <= 96999999) ~ 99,
    (kad >= 97000000 & kad <= 97999999) ~ 100,
    (kad >= 98000000 & kad <= 98999999) ~ 101,
    (kad >= 99000000 & kad <= 99999999) ~ 102,
    TRUE ~ NA_real_
  ))

table(df$sector
      )
######################
  #Labels

df <- df %>%
  mutate(sector_label = case_when(
    sector == 1 ~ "other",
    sector == 2 ~ "others",
    sector == 3 ~ "_other_",
    sector == 4 ~ "01_AGRICULTURE, HUNTING AND RELATED SERVICE ACTIVITIES",
    sector == 5 ~ "02_FORESTRY, LOGGING AND RELATED SERVICE ACTIVITIES",
    sector == 6 ~ "03_ FISHING, FISH FARMING AND RELATED SERVICE ACTIVITIES",
    sector == 7 ~ "04_",
    sector == 8 ~ "05_ MINING OF COAL AND LIGNITE",
    sector == 9 ~ "06_ Extraction of crude petroleum and natural gas",
    sector == 10 ~ "07_ MINING OF METAL",
    sector == 11 ~ "08_other MINING ACTIVITIES",
    sector == 12 ~ "09_SUPPORTIVE MINING ACTIVITIES",
    sector == 13 ~ "10_ MANUFACTURE OF FOOD PRODUCTS AND BEVERAGES",
    sector == 14 ~ "11_PRODUCTION OF DRINKS",
    sector == 15 ~ "12_ MANUFACTURE OF TOBACCO PRODUCTS",
    sector == 16 ~ "13_ MANUFACTURE OF TEXTILES",
    sector == 17 ~ "14_ MANUFACTURE OF WEARING APPAREL; DRESSING",
    sector == 18 ~ "15_ MANUFACTURE OF LEATHER AND LEATHER PRODUCTS",
    sector == 19 ~ "16_ MANUFACTURE OF WOOD AND WOOD PRODUCTS",
    sector == 20 ~ "17_ MANUFACTURE OF PULP, PAPER AND PAPER PRODUCTS;",
    sector == 21 ~ "18_ PUBLISHING, PRINTING AND REPRODUCTION OF MEDIA",
    sector == 22 ~ "19_ MANUFACTURE OF COKE, REFINED PETROLEUM PRODUCTS AND NUCLEAR FUEL",
    sector == 23 ~ "20_ MANUFACTURE OF CHEMICALS AND CHEMICAL PRODUCTS",
    sector == 24 ~ "21_MANUFACTURE OF PHARMACEUTICAL PRODUCTS",
    sector == 25 ~ "22_ MANUFACTURE OF RUBBER AND PLASTIC PRODUCTS",
    sector == 26 ~ "23_ MANUFACTURE OF OTHER NON- METALLIC MINERAL PRODUCTS",
    sector == 27 ~ "24_ MANUFACTURE OF BASIC METALS",
    sector == 28 ~ "25_ MANUFACTURE OF FABRICATED METAL PRODUCTS, EXCEPT MACHINERY AND EQUIPMENT",
    sector == 29 ~ "26_MANUFACTURE OF PC AND OPTICAL EQUIPMENT",
    sector == 30 ~ "27_ MANUFACTURE OF ELECTRICAL EQUIPMENT",
    sector == 31 ~ "28_MANUFACTURE OF MACHINERY",
    sector == 32 ~ "29_ MANUFACTURE OF MOTOR VEHICLES, TRAILERS AND SEMI-TRAILERS",
    sector == 33 ~ "30_ MANUFACTURE OF OTHER TRANSPORT EQUIPMENT",
    sector == 34 ~ "31_ MANUFACTURE OF FURNITURE",
    sector == 35 ~ "32_ Miscellaneous manufacturing",
    sector == 36 ~ "33_REPAIRING MACHINERY AND EQUIPMENT",
    sector == 37 ~ "34_",
    sector == 38 ~ "35_ ELECTRICITY, GAS SUPPLY",
    sector == 39 ~ "36_Collection, purification and distribution of water",
    sector == 40 ~ "37_ WASTE PURIFICATION",
    sector == 41 ~ "38_ WASTE Collection, purification and distribution",
    sector == 42 ~ "39_WASTE MANAGEMENT SERVICES",
    sector == 43 ~ "40_",
    sector == 44 ~ "41_BUILDINGS CONSTRUCTION",
    sector == 45 ~ "42_CIVIL ENGINEERING PROJECTS",
    sector == 46 ~ "43_SPECIAL CONSTRUCTION ACTIVITIES",
    sector == 47 ~ "44_",
    sector == 48 ~ "45_ WHOLESALE AND RETAIL TRADE; REPAIR OF MOTOR VEHICLES, MOTORCYCLES",
    sector == 49 ~ "46_ WHOLESALE TRADE EXCEPT FROM MOTOR VEHICLES, MOTORCYCLES",
    sector == 50 ~ "47_ RETAIL TRADE EXCEPT FROM MOTOR VEHICLES, MOTORCYCLES",
    sector == 51 ~ "48_",
    sector == 52 ~ "49_ LAND TRANSPORT",
    sector == 53 ~ "50_WATER TRANSPORT",
    sector == 54 ~ "51_AIR TRANSPORT",
    sector == 55 ~ "52_ STORAGE AND AUXILIARY TRANSPORT ACTIVITIES",
    sector == 56 ~ "53_ Post and courier activities",
    sector == 57 ~ "54_",
    sector == 58 ~ "55_HOTELS",
    sector == 59 ~ "56_ Restaurants",
    sector == 60 ~ "57_",
    sector == 61 ~ "58_PUBLISHING ACTIVITIES",
    sector == 62 ~ "59_ Production of recorded media",
    sector == 63 ~ "60_ Radio and television activities",
    sector == 64 ~ "61_Telecommunications",
    sector == 65 ~ "62_computer programming, advisory services",
    sector == 66 ~ "63_information processing activities",
    sector == 67 ~ "64_ FINANCIAL INTERMEDIATION, EXCEPT INSURANCE AND PENSION FUNDING",
    sector == 68 ~ "65_ INSURANCE AND PENSION FUNDING, EXCEPT COMPULSORY SOCIAL SECURITY",
    sector == 69 ~ "66_ ACTIVITIES AUXILIARY TO FINANCIAL INTERMEDIATION",
    sector == 70 ~ "67_",
    sector == 71 ~ "68_ REAL ESTATE ACTIVITIES",
    sector == 72 ~ "69_ Legal, accounting, book-keeping and auditing activities",
    sector == 73 ~ "70_Management advisory activities",
    sector == 74 ~ "71_ Architectural and engineering activities",
    sector == 75 ~ "72_ RESEARCH AND DEVELOPMENT",
    sector == 76 ~ "73_Advertising and market research activities",
    sector == 77 ~ "74_ Miscellaneous scientific, professional and technical",
    sector == 78 ~ "75_ veterinarian services",
    sector == 79 ~ "76_",
    sector == 80 ~ "77_renting activities",
    sector == 81 ~ "78_ Labour recruitment and provision of personnel",
    sector == 82 ~ "79_TRAVEL AGENCY ACTIVITIES",
    sector == 83 ~ "80_ Investigation and security activities",
    sector == 84 ~ "81_ Miscellaneous services to buildings and outside",
    sector == 85 ~ "82_SECRETARIAL AND ADMINISTRATIVE ACTIVITIES SUPPORTIVE TO BUSINESSES",
    sector == 86 ~ "83_",
    sector == 87 ~ "84_ PUBLIC ADMINISTRATION AND DEFENCE; COMPULSORY SOCIAL SECURITY",
    sector == 88 ~ "85_ EDUCATION",
    sector == 89 ~ "86_ Human health activities",
    sector == 90 ~ "87_HOME CARE ACTIVITIES",
    sector == 91 ~ "88_ Social work activities without accommodation",
    sector == 92 ~ "89_",
    sector == 93 ~ "90_ RECREATIONAL, CULTURAL AND CREATIVE ACTIVITIES",
    sector == 94 ~ "91_ Library, archives, museums and other cultural activities",
    sector == 95 ~ "92_ Gambling and betting activities",
    sector == 96 ~ "93_ Sporting and recreational activities",
    sector == 97 ~ "94_ ACTIVITIES OF MEMBERSHIP ORGANIZATIONS",
    sector == 98 ~ "95_Repair of computer and personal items",
    sector == 99 ~ "96_ Other service activities",
    sector == 100 ~ "97_ PRIVATE HOUSEHOLDS EMPLOYING DOMESTIC STAFF",
    sector == 101 ~ "98_ UNDIFFERENTIATED GOODS PRODUCING ACTIVITIES OF PRIVATE HOUSEHOLDS FOR OWN USE",
    sector == 102 ~ "99_EXTRA - TERRITORIAL ORGANIZATIONS AND BODIES",
    TRUE ~ NA_character_
  ))


# * Standardized NACE rev 2 code
# * example with division
# MANUAL TENTATIVE, not clear whether sector codes are cleaned properly
df <- df %>%
  mutate(section = case_when(
    sector > 0 & sector <= 3 ~ "",
    sector > 3 & sector <= 6 ~ "A",
    sector > 7 & sector <= 12 ~ "B",
    sector > 12 & sector <= 36 ~ "C",
    sector > 37 & sector <= 38 ~ "D",
    sector > 38 & sector <= 42 ~ "E",
    sector > 43 & sector <= 46 ~ "F",
    sector > 47 & sector <= 50 ~ "G",
    sector > 51 & sector <= 56 ~ "H",
    sector > 57 & sector <= 59 ~ "I",
    sector > 60 & sector <= 66 ~ "J",
    sector > 66 & sector <= 69 ~ "K",
    sector > 70 & sector <= 74 ~ "L",
    sector > 74 & sector <= 81 ~ "M",
    sector > 81 & sector <= 85 ~ "N",
    sector > 86 & sector <= 87 ~ "O",
    sector > 87 & sector <= 88 ~ "P",
    sector > 88 & sector <= 91 ~ "Q",
    sector > 92 & sector <= 96 ~ "R",
    sector > 96 & sector <= 99 ~ "S",
    sector > 99 & sector <= 101 ~ "T",
    sector > 101 & sector <= 102 ~ "U",
    TRUE ~ ""
  ))

# Use mutate to create the descr_section variable
df <- df %>%
  mutate(descr_section = case_when(
    section == "A" ~ "AGRICULTURE, FORESTRY AND FISHING",
    section == "B" ~ "MINING AND QUARRYING",
    section == "C" ~ "MANUFACTURING",
    section == "D" ~ "ELECTRICITY, GAS, STEAM AND AIR CONDITIONING SUPPLY",
    section == "E" ~ "WATER SUPPLY; SEWERAGE, WASTE MANAGEMENT AND REMEDIATION ACTIVITIES",
    section == "F" ~ "CONSTRUCTION",
    section == "G" ~ "WHOLESALE AND RETAIL TRADE; REPAIR OF MOTOR VEHICLES AND MOTORCYCLES",
    section == "H" ~ "TRANSPORTATION AND STORAGE",
    section == "I" ~ "ACCOMMODATION AND FOOD SERVICE ACTIVITIES",
    section == "J" ~ "INFORMATION AND COMMUNICATION",
    section == "K" ~ "FINANCIAL AND INSURANCE ACTIVITIES",
    section == "L" ~ "REAL ESTATE ACTIVITIES",
    section == "M" ~ "PROFESSIONAL, SCIENTIFIC AND TECHNICAL ACTIVITIES",
    section == "N" ~ "ADMINISTRATIVE AND SUPPORT SERVICE ACTIVITIES",
    section == "O" ~ "PUBLIC ADMINISTRATION AND DEFENSE; COMPULSORY SOCIAL SECURITY",
    section == "P" ~ "EDUCATION",
    section == "Q" ~ "HUMAN HEALTH AND SOCIAL WORK ACTIVITIES",
    section == "R" ~ "ARTS, ENTERTAINMENT AND RECREATION",
    section == "S" ~ "OTHER SERVICE ACTIVITIES",
    section == "T" ~ "ACTIVITY OF HOUSEHOLDS AS EMPLOYERS; ACTIVITIES OF HOUSEHOLDS FOR OWN USE",
    section == "U" ~ "ACTIVITY OF EXTRATERRITORIAL ORGANIZATIONS AND BODIES",
    TRUE ~ "Other"
  ))

#------------->
table(df$section)
#-------------< 

# GROUP 7: FIRM CHARACTERISTICS
df <- df %>% mutate(
  capital_city = NA_real_,
  region = NA_real_,
  city = NA_real_,
  tax_center = NA_real_,
  incorporation = as.numeric(substr(start, nchar(start) - 3, nchar(start))),
  firm_age = if_else(year <incorporation, 0, year - incorporation),
  nb_employee = empl, # empl has only 20 obs non missing,
  total_assets = ta, # ta,# ta has only one non-missing value in 2018 
  private = NA_real_,
  FEZ = NA_real_,
  
  foreign_ownership = if_else(legal_status >= 86 & legal_status <= 95, 1, 0),
  # foreign investors, 86
  # foreign company of real estate property, 87
  # foreign company member not natural persons, 88
  # branch of foreign company, 89
  # foreign company with specific contract, 92
  # foreign company office, 93
  # foreign company of compulsory deposit, 94
  # representative office of foreign bank 95
  
  MNE_branch = if_else(legal_status == 89 , 1, 0),
  
  # Net tangible assets are all the physical assets a company owns less any intangible assets and liabilities.
  sum_fixed_assets = rowSums(select(. , land_, buildings, intangibles, accum_deprec, participat, equipment)),
  tangible_assets = net_fixed_assets - intangibles,
  intangible_assets = intangibles
  
)

# GROUP 8: Statutory Tax Rate 

# With the exception of credit organizations, the Greece corporate tax rate is assessed at a fixed rate of 22%, 
# which was lowered from 24% in the year 2021. 
# Additionally, credit institutions are subject to a 29% tax

df <- df %>% mutate(STR = NA_real_,
                    STR = if_else(year >= 2002 & year <= 2004, 0.35, STR),
                    STR = if_else(year == 2005, 0.32, STR),
                    STR = if_else(year == 2006, 0.29, STR),
                    STR = if_else(year >= 2007 & year <= 2009, 0.25, STR),
                    STR = if_else(year == 2010, 0.24, STR),
                    STR = if_else(year >= 2011 & year <= 2012, 0.20, STR),
                    STR = if_else(year >= 2013 & year <= 2014, 0.26, STR),
                    STR = if_else(year >= 2015 & year <= 2018, 0.29, STR),
                    STR = if_else(year == 2019, 0.28, STR),
                    STR = if_else(year == 2020 | year == 2021, 0.24, STR),
                    STR = if_else(year >= 2022 , 0.22, STR)) 

df <- df %>% select(-V1)

#------------->Check Foreign ownership status and Orbis match

#FYI: Foreign status is defined as: 
# foreign_ownership = if_else(legal_status >= 86 & legal_status <= 95, 1, 0),
# foreign investors, 86
# foreign company of real estate property, 87
# foreign company member not natural persons, 88
# branch of foreign company, 89
# foreign company with specific contract, 92
# foreign company office, 93
# foreign company of compulsory deposit, 94
# representative office of foreign bank 95
  
df %>% group_by(orbis_match, foreign_ownership) %>% summarise(n())

### Do it for 2018 only:
df %>% filter(year == 2018) %>% group_by(orbis_match, foreign_ownership) %>% 
  summarise(n())


## Get values at the firm level */
temp <- df %>% group_by(tax_ID) %>% select(foreign_ownership, orbis_match) %>% fmean() %>% 
  mutate(foreign_ownership = if_else(foreign_ownership!= 1 & foreign_ownership!=0, 1, foreign_ownership))
temp %>% group_by(orbis_match, foreign_ownership) %>% 
  summarise(n())

## Recode the foreign owned firms:
df <- df %>% mutate(foreign_ownership = case_when(orbis_match == 1 ~ 1, 
                                                  TRUE ~ foreign_ownership))
df <- df %>% 
  mutate(group = as.integer(factor(GUO_BVD_ID_NUMBER, levels = unique(GUO_BVD_ID_NUMBER))))

gc()


#### Estimates LASSO labor and tangible assets: 
setwd(data)
df.lasso <- read.csv("GRC_Lasso_Estimates.csv") 

df <- left_join(df, df.lasso, by = c("year", "tax_ID"))

df <- df %>% rename(labor_data = labor_inp,
                    tangible_assets_data = tangible_assets) %>% 
  mutate(tangible_assets = tangible_asset_lasso,
         labor_inp = 20000*empl_lasso)

write.csv(df, "GRC_withvars.csv")