*===============================================================================
* File name: 		CIT_HDN.do
* 
* Description:		This do-file creates the dataset HDN_withvars.csv. 
*
* Input:  					
*					$data/input/Honduras/CIT_Dataset_26_4_2022.dta 
*					$data/input/Honduras/GUO_ISRPJ_2014_2020_0305_WB.dta
*
* Output:
*					$data/output/Honduras/HDN_withvars.csv
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

*****************************************************************************
**************************** LEGAL ENTITIES *********************************
*****************************************************************************

/* Load data */
use "$data/input/Honduras/CIT_Dataset_26_4_2022.dta" , clear

******** SELECT AND CREATE VARIABLES ********
* GROUP 0
	* Indentification variables
*rename   year
rename id tax_ID
generate country = "HND"
generate entity = "Legal"	

	* Check for duplicates and drop
duplicates report year tax_ID

	* Tax Form
tostring nro_preimpreso, gen(tax_form) format("%12.0f")
replace tax_form = substr(tax_form, 1, 3)

* GROUP 1: INCOMES
	* Turnover 
egen turnover_exempt = rowtotal(ingr_vtas_grav_18_art22 ingr_vtas_grav_15_art22 ingr_vtas_grav_12_art22 ingr_vtas_serv_expor_art22 ingr_vtas_servicios_exe_art22 ingr_vtas_serv_fyduca_art22), missing

egen turnover_taxed = rowtotal(ingr_vtas_grav_12 ingr_vtas_grav_15 ingr_vtas_grav_18 ingr_vtas_serv_expor ingr_vtas_servicios_exe ingr_vtas_serv_fyduca), missing

egen turnover = rowtotal(turnover_exempt turnover_taxed), missing
replace turnover =  round(total_ingresos_resul_ejercicio, 1) if tax_form!="357"
	* Other income 
egen other_inc_exempt = rowtotal(ingr_int_no_bancarios_art22 ingr_alq_exe_isv_art22  ingr_por_intereses_art22  ingr_por_comisiones_art22  ingr_por_donac_locales_art22 ///
ingr_por_donaciones_ext_art22 ingr_intereses_banc_art22 ingr_ganancias_capital_art22 ingr_seguros_art22 ingr_dividendos_art22 ingr_bienes_herencia_art22 ingr_renta_titulos_art22 ingr_subversiones_art22 ingr_premios_loteria_art22 ingr_loteria_electr_art22 ingr_otra_rentas_no_grav_art22 ingr_prov_exterior_art22 ingr_ganan_mediciones_art22), missing

egen other_inc_taxed = rowtotal(ingr_int_no_bancarios_v ingr_alq_exe_isv ingr_por_intereses ingr_por_comisiones ingr_por_donac_locales ingr_prov_exterior ingr_otra_renta_grav ingrajustespreciostransf), missing

egen other_income = rowtotal(other_inc_exempt other_inc_taxed), missing

	* Exempt income (is already counted in the above)
gen exempt_income = ct_ingresos_no_gravados
egen exempt_income_built =rowtotal(turnover_exempt other_inc_exempt), missing

gen dividend_income = ingr_dividendos_art22
gen dividend_exempt = ct_dividendos
replace dividend_exempt=0 if dividend_exempt==.
replace dividend_income=0 if dividend_income==.


	* Total income (all income)
egen total_income_built = rowtotal(turnover other_income), missing
gen total_income = round(ingr_total_ingresos_total, 1)
replace total_income =  round(total_ingresos_resul_ejercicio, 1) if tax_form!="357"
	* Taxable income (-exempt income)
gen taxable_income_built = total_income - cond(missing(exempt_income), 0, exempt_income)
gen taxable_income = round(total_ingresos_resul_ejercicio, 1)
	
* GROUP 2: COST ITEMS
	* Cost of Goods Sold 
gen cogs = .	

	* Labor Inputs
egen labor_inp = rowtotal(cyg_gastos_com_vtas_c cygsueldossalariosc cyg_honorarios_prof_c cyg_honorarios_extranj_c ///
cyg_gastos_com_vtas_g cygsueldossalariosg cyg_honorarios_prof_g cyg_cyg_honorarios_extranj_g), missing

	* Material Inputs
	gen compra_venta = cyginvinicialbienesc+cygcomprasbrutaslocalc+cygcomprasimportbienesc - cygdescdevcomprasc - cyginvfinalbienesc
	
	gen costos_de_prod = cyginvinicialmatprimac + cygcomprasnetasmatprimac + cygimportacionmatprimac + cyggastosindirfabrc + ///
	cyginvinicialprodprocc + cyginvinicialprodtermc + cygmanoobradirc + cygmanoobraindirc /// direct labor 
	- cyginvfinalmatprimac - cyginvfinalprodprocc  - cyginvfinalprodtermc 
	
egen material_inp = rowtotal(compra_venta costos_de_prod cyg_gastos_compra_c cyg_gastos_compra_g ), missing
replace material_inp = 0 if material_inp < 0 
			
	* Selling, admin and other operating costs
egen operating_inp = rowtotal(cyg_arrendamientos_c cyg_arrendamientos_g  cyg_mantenimiento_rep_c cyg_mantenimiento_rep_g  ///
cyg_combustibles_lubric_c cyg_combustibles_lubric_g  cyg_publicidad_propaganda_c cyg_publicidad_propaganda_g  cyg_suministros_mat_c cyg_suministros_mat_g  cyg_transporte_c cyg_transporte_g  cyg_gastos_ind_asig_ext_c cyg_gastos_ind_asig_ext_g  ///
cyg_gastos_g_imp_c cyg_gastos_g_imp_g  cyg_gastos_viaje_c cyg_gastos_viaje_g  cyg_gastos_representacion_c cyg_gastos_representacion_g  cyg_servicios_publicos_c cyg_servicios_publicos_g  cyg_pagos_otros_servicios_c cyg_pagos_otros_servicios_g  cyg_pagos_otros_bienes_c cyg_pagos_otros_bienes_g  cyg_isv_carga_costo_c cyg_isv_carga_costo_g  ///
cyg_beneficios_sociales_g  cyg_capacitacion_g cyg_capacitacion_vnd cyg_informatica_g  cyg_gastos_seguro_g  cyg_gastos_vigilancia_g  cyg_gastos_años_ant_g  cyg_producto_financiero_g ), missing

	* Capital Inputs
gen capital_inp = .
	* Financial Inputs
egen financial_inp = rowtotal(intereses_banc_local intereses_banc_exterior intereses_terc_local_er intereses_terc_exterior_er ///
		 intereses_terc_local_enr intereses_terc_exterior_enr local_int_bancarios_int delext_bancarios_int ///
		 local_empresas_rel_int delext_empresas_rel_int local_empresas_no_rel_int delext_empresas_norel_int), missing 
		 
	* Depreciation 
egen depreciation = rowtotal(cyg_depreciacion_aceler_c cyg_depreciacion_aceler_g  cyg_depreciacion_noacel_c cyg_depreciacion_noacel_g  cyg_depreciacion_rev_pro_c cyg_depreciacion_rev_pro_g  cyg_agot_activos_expl_c cyg_agot_activos_expl_g  cyg_otras_amortizaciones_c cyg_otras_amortizaciones_g ), missing
	
	* Accelerated depreciation 
egen acc_depreciation = rowtotal(cyg_depreciacion_aceler_c cyg_depreciacion_aceler_g cyg_depreciacion_aceler_vnd), missing
		
	* Other Inputs
egen other_inp = rowtotal(cyg_otros_costos_gastos_c cyg_otros_costos_gastos_g ///
cyg_cuentas_cobrar_g  cyg_inventarios_c cyg_inventarios_g  cyg_arrend_exterior_c cyg_arrend_exterior_g  cyg_arrend_local_c cyg_arrend_local_g  cyg_comisiones_exterior_c  cyg_comisiones_local_c cyg_comisiones_local_g  delext_comisiones_int cyg_otras_peridas_c cyg_otras_peridas_g  cyg_seguros_reaseguros_c cyg_seguros_reaseguros_g  cyg_perdida_vtas_act_norel_g  cyg_perdida_vtas_act_rel_g  ///
cyg_perd_medicion_c cyg_perd_medicion_g   ///
cyg_gnd_reparar_daños_nat_g   cyg_gast_personales_g cyg_inversiones_g  cyg_sueldos_obsequios_grat_g  cyg_int_cap_invertidos_g  cyg_perd_capital_inv_g  cyg_contr_especial_seg_pob_g  cyg_multas_recargos_g  cyg_doc_no_cumplen_ley_g  cyg_impt_rj_an_ap_g  cyg_otros_gasto_no_deduc_g  cyg_gastos_otras_prov_g ), missing 

 	* Non deductible Inputs
gen non_deduc_inp = round(ct_gastos_no_deducibles, 1)

 	* Total costs: add up all costs & expenditure
egen tot_cost_built = rowtotal(capital_inp material_inp operating_inp labor_inp financial_inp depreciation other_inp), missing // only for firm 357
replace tot_cost_built = 0 if tot_cost_built < 0
gen tot_cost_dataset = round(cyg_total_gastos_gastos_c , 1) 
sum tot_cost_built tot_cost_dataset  if tax_form == "357"
gen tot_cost = tot_cost_dataset

	* Deductible Costs: total costs - non-deductible inputs 
gen deductible_cost_built = tot_cost_dataset - cond(missing(non_deduc_inp), 0, non_deduc_inp)  

gen deductible_cost = round(total_deduc_del_ejerc, 1)
sum deductible_cost deductible_cost_built if tax_form == "357"

* GROUP 3: PROFITS
	* Gross profit
gen gross_profit = .

	* Net profit
gen net_profit_data = cyg_utilidad_ejercicio 
replace net_profit_data = -1*cyg_perdida_ejercicio if net_profit_data == 0
gen net_profit = total_income - tot_cost_dataset  // profit
replace net_profit = round(net_profit, 1)
sum net_profit net_profit_data  

	* Taxable profit
gen taxable_profit = taxable_income - cond(missing(deductible_cost), 0, deductible_cost)

* GROUP 4: GROSS & NET TAX BASE
	* Investment Incentives  (From tax base)
gen investment_taxbase = .
	* Capital allowances  (From tax base)
gen capital_allowance = .
	* Losses (always from tax base)
gen loss_carryforward = arrastperdidaart20
	* Other Deductions (always from tax base)
gen other_ded_taxbase = ctmontobeneficio
	* Add up credits & deductions from tax base: 
egen tot_deduc_taxbase = rowtotal(investment_taxbase capital_allowance other_ded_taxbase), missing 

gen double precio_trans_ing = ingreautoajustepreciostran + ingrajustespreciostransf
replace precio_trans_ing = 0 if (abs(ingreautoajustepreciostran - ingrajustespreciostransf)<1 & ingreautoajustepreciostran!=0)

	* Gross tax base (taxable_profit - tot_deduc_taxbase)
gen gross_tax_base = taxable_profit - tot_deduc_taxbase + perdidaporactiart20 + precio_trans_ing

* NET TAX BASE (gross_tax_base - loss_carryforward) 

*1) CIT (ISR):
gen net_tax_base_built = gross_tax_base - loss_carryforward
gen net_tax_base = round(baseimponrtanetagrav, 1.0) 

*2) Solidarity tax: 5% surcharge to the excess L1million of net tax base
gen solidarity_tax_base = round(baseimponaportsolidaria, 1) // = min(net_tax_base-1Million , 0)

*3) Net asset tax (IAN): 1% on the excess L3million of total assets 
gen asset_tax_base = round(baseimponactivoneto, 1) // = min(Total Asset-3Million , 0)

*4) Minimum Income tax (base is taxable income)
gen min_tax_base = round(total_ingresos_resul_ejercicio,1) 
sum net_tax_base net_tax_base_built 

* GROUP 5: GROSS & NET TAX LIABILITY

* LIABILITY
*1) Mininum tax
gen porcentaje_ing_brutos_correct = porcentaje_ing_brutos
replace porcentaje_ing_brutos_correct = 0 if baseimponrtanetagrav <=0 

*2) Minimum tax/ISR
gen max_ISR_IM = max(porcentaje_ing_brutos_correct, imp_segun_tarifa_renta)
* Add solidarity surcharge
gen max_AS = max_ISR_IM + imp_segun_tarifa_aport_solid	

* Identidy the caused tax: Minimum Tax, Net Asset Tax, CIT or None
gen causa_impuesto = .
* None
replace causa_impuesto = 0 if max(max_AS, imp_segun_tarifa_activo_neto) == 0

* CIT
replace causa_impuesto = 1 if max(max_AS, imp_segun_tarifa_activo_neto) == max_AS & ///
	max(porcentaje_ing_brutos_correct,imp_segun_tarifa_renta) == imp_segun_tarifa_renta	& ///
	max(max_AS, imp_segun_tarifa_activo_neto) > 0

* Asset 	
replace causa_impuesto = 2 if max(max_AS, imp_segun_tarifa_activo_neto) == imp_segun_tarifa_activo_neto & ///
	max(max_AS, imp_segun_tarifa_activo_neto) > 0

* MIT	
replace causa_impuesto = 3 if max(max_AS, imp_segun_tarifa_activo_neto) == max_AS & ///
	max(porcentaje_ing_brutos_correct,imp_segun_tarifa_renta) == porcentaje_ing_brutos_correct & ///
   	max(max_AS, imp_segun_tarifa_activo_neto) > 0  
	
lab def causa_impuesto 0"None" 1"CIT" 2"Asset tax" 3"Minimum Income Tax"
lab val causa_impuesto causa_impuesto

tab causa_impuesto, gen(causa_impuesto_)

gen double impuesto_causado = .
replace impuesto_causado = 0 		 						if causa_impuesto == 0
replace impuesto_causado = max_AS 							if causa_impuesto == 1
replace impuesto_causado = imp_segun_tarifa_activo_neto 	if causa_impuesto == 2
replace impuesto_causado = max_AS 							if causa_impuesto == 3
label var impuesto_causado "Impuesto causado real"

gen imp_base_final= .
replace imp_base_final=1 if max(imp_segun_tarifa_renta,imp_segun_tarifa_activo_neto)==imp_segun_tarifa_renta
replace imp_base_final=2 if max(imp_segun_tarifa_renta,imp_segun_tarifa_activo_neto)==impuesto_pagar_activ_neto_liq

/* Theoretical tax rate */
gen rent_rate=imp_segun_tarifa_renta/baseimponrtanetagrav*100
gen asset_rate=imp_segun_tarifa_activo_neto/baseimponactivoneto*100
gen ap_rate=imp_segun_tarifa_aport_solid/baseimponaportsolidaria*100

order rent_rate asset_rate ap_rate, a(tasa_aplicada)

replace rent_rate=round(rent_rate,1)
replace asset_rate=round(asset_rate,1)
replace ap_rate=round(ap_rate,1)

/* Reorganize variables */
order tax_ID year tasa_aplicada rent_rate asset_rate ap_rate baseimponrtanetagrav baseimponactivoneto baseimponaportsolidaria total_creditos_rta total_creditos_act_neto total_creditos_as impuesto_a_pagar_rta_liq impuesto_pagar_activ_neto_liq impuesto_a_pagar_as_liq valor_impuesto valor_impuesto_an valor_impuesto_as

	* Gross tax liability (net tax base*CIT rate) or MIT
gen gross_tax_liability = impuesto_causado
gen gross_tax_liability_as=imp_segun_tarifa_aport_solid

gen tax_paid = ""
replace tax_paid = "CIT" if causa_impuesto == 1
replace tax_paid = "Asset tax" if causa_impuesto == 2
replace tax_paid = "Minimum Income Tax" if causa_impuesto == 3

tab tasa_aplicada tax_paid

	* Credits for foreign taxes paid
gen cred_foreign_tax = .
	
	* Investment credits from tax liability
egen investment_taxliab_CIT = rowtotal(cre_credi_gene_nuevos_empl cre_importe_exo_red_rta cre_importe_exo_aport_soli), missing
egen investment_taxliab_ASSET = rowtotal(cre_importe_exo_red_act_neto), missing

gen investment_taxliab=0
replace investment_taxliab=investment_taxliab_CIT if tax_paid == "CIT"
replace investment_taxliab=investment_taxliab_ASSET if tax_paid == "Asset tax"

	* Special firms credits from tax liability
gen special_taxliab = .
	* International Trade credits 
gen trade_taxliab = .
	* Other credit and allowances from tax liability
egen other_cred_taxliab_CIT = rowtotal(cre_cesiones_credi_recib_rta  cre_cesiones_cred_recib_as), missing
egen other_cred_taxliab_ASSET = rowtotal(cre_cesiones_cred_recib_ac_net ), missing 

gen other_cred_taxliab=0
replace other_cred_taxliab=other_cred_taxliab_CIT if tax_paid == "CIT"
replace other_cred_taxliab=other_cred_taxliab_ASSET if tax_paid == "Asset tax"

	 *Add up credits & deductions from tax liability 
egen tot_deduc_taxliab = rowtotal(cred_foreign_tax special_taxliab trade_taxliab investment_taxliab other_cred_taxliab), missing
	* Add up credits & deductions that are not necessarily real credits from tax liability 
egen tot_noelse_taxliab = rowtotal(cred_foreign_tax  other_cred_taxliab), missing

	* Net tax liability (gross_tax_liability - tot_deduc_taxliab)
gen net_tax_liability = gross_tax_liability - cond(missing(tot_deduc_taxliab), 0, tot_deduc_taxliab)
gen net_tax_liability_as  = impuesto_a_pagar_as_liq
	* Net tax liability without foreign and other credits  
gen ntl_noelse = net_tax_liability + cond(missing(tot_noelse_taxliab), 0, tot_noelse_taxliab)

* GROUP 6: WITHHOLDING. ADVANCED/PARTIAL PAYMENTS & OTHER CREDITABLE TAX PAYMENTS
	* Add up partial/advance payments
egen partial_advanced_pay_CIT = rowtotal( /*176*/ cre_pagos_cuenta_rta cre_pagos_cuenta_as ///
									  /*177*/ cre_exe_ejer_fiscal_ant_rta cre_excedente_ejer_ant_as ///
									  /*721*/ pagos_anti_isr_decre96_2012 ///
									  /*181*/ cre_import_compensacion_rta ///
									cre_import_compensacion_as), missing
									
egen partial_advanced_pay_ASSET = rowtotal(cre_exe_ejer_fis_ant_ac_neto cre_import_compensa_act_neto), missing

gen partial_advanced_pay=0
replace partial_advanced_pay=partial_advanced_pay_CIT if tax_paid == "CIT"
replace partial_advanced_pay=partial_advanced_pay_ASSET if tax_paid == "Asset tax"

egen withholding_CIT = rowtotal(/*175*/ cre_retencion_art50_ley_rta ///
							/*703*/ cre_reten_anti_isr_o_atn_rta ///
							/*712*/ cre_retencion_anti_irs_impor  /// Retencion por Anticipo ISR por importaciones
							/*179*/ cre_pagos_reali_periodo_rta cre_pagos_reali_periodo_as ///
							/*713*/ creditos_apli_pagos_cuenta_rta creditos_apli_pagos_cuenta_as), missing
							
egen withholding_ASSET = rowtotal(cre_ret_anti_isr_o_atn_act_net ///
							cre_reten_compra_venta ///
							cre_isr_activo_neto ///
							/*179*/ cre_pagos_reali_peri_act_net), missing
							
gen withholding=0
replace withholding=withholding_CIT if tax_paid == "CIT"
replace withholding=withholding_ASSET if tax_paid == "Asset tax"

	* Other creditable tax payments
egen other_cred_tax_pay_CIT   = rowtotal(otros_creditos_rta otros_creditos_as), missing
egen other_cred_tax_pay_ASSET = rowtotal(otros_creditos_act_neto ), missing

gen other_cred_tax_pay=0
replace other_cred_tax_pay=other_cred_tax_pay_CIT if tax_paid == "CIT"
replace other_cred_tax_pay=other_cred_tax_pay_ASSET if tax_paid == "Asset tax"

	* Tax to remit
gen impuesto_pagar_renta = imp_segun_tarifa_renta - total_creditos_rta - cre_import_compen_exce_rta

gen impuesto_pagar_an = imp_segun_tarifa_activo_neto - total_creditos_act_neto - cre_import_compen_exce_act_net 

gen impuesto_pagar_as = imp_segun_tarifa_aport_solid - total_creditos_as - cre_import_compen_exce_as

replace impuesto_pagar_renta = 0 if impuesto_pagar_renta < 0
replace impuesto_pagar_an = 0 if impuesto_pagar_an < 0
replace impuesto_pagar_as = 0 if impuesto_pagar_as < 0

* Gather tax to remit
gen tax_to_remit = .
replace tax_to_remit = 0 if causa_impuesto == 0
replace tax_to_remit = impuesto_pagar_renta+impuesto_pagar_as if causa_impuesto == 1
replace tax_to_remit = impuesto_pagar_an if causa_impuesto == 2
replace tax_to_remit = impuesto_pagar_renta+impuesto_pagar_as if causa_impuesto == 3

**** Treatment of missings and 0
foreach var of varlist gross_tax_base net_tax_base gross_tax_liability net_tax_liability tax_to_remit {
    replace `var' = 0 if missing(`var') & !missing(total_income)
}

********* Add labels and drop some variables ********
label variable tax_ID "Tax ID"
label variable year "Fiscal Year"
label variable turnover "Turnover"
label variable total_income "Total income"
label variable taxable_income "Taxable income"
label variable tot_cost "Total Costs"
label variable deductible_cost "Deductible Costs"
label variable net_profit "Net profit"
label variable taxable_income "Taxable profit"
label variable gross_tax_base "Gross Tax Base"
label variable tot_deduc_taxbase "Total Credits & Deductions - Tax Base"
label variable net_tax_base "Net Tax Base"
label variable gross_tax_liability "Gross Tax Liability"
label variable net_tax_liability "Net Tax Liability"
label variable tot_deduc_taxliab "Total Credits & Deductions - Tax Liability"
label variable tax_to_remit "Tax to Remit"
label variable country "Country"

**********************************************************************
foreach var of varlist turnover - tax_to_remit{
	cap sum `var' if tax_form != "357"
	 if r(max) == 0 {
	cap replace `var' = . if tax_form != "357"
	}
}

**** ADD sectors 
gen section =  codigoseccion
replace section = "" if  codigoseccion == "-1"
gen descr_section = ""

replace descr_section = "AGRICULTURE, FORESTRY AND FISHING" if section == "A"
replace descr_section = "MINING AND QUARRYING" if section == "B"
replace descr_section = "MANUFACTURING" if section == "C"
replace descr_section = "ELECTRICITY, GAS, STEAM AND AIR CONDITIONING SUPPLY" if section == "D"
replace descr_section = "WATER SUPPLY; SEWERAGE, WASTE MANAGEMENT AND REMEDIATION ACTIVITIES" if section == "E"
replace descr_section = "CONSTRUCTION" if section == "F"
replace descr_section = "WHOLESALE AND RETAIL TRADE; REPAIR OF MOTOR VEHICLES AND MOTORCYCLES" if section == "G"
replace descr_section = "TRANSPORTATION AND STORAGE" if section == "H"
replace descr_section = "ACCOMODATION AND FOOD SERVICE ACTIVITIES" if section == "I"
replace descr_section = "INFORMATION AND COMMUNICATION" if section == "J"
replace descr_section = "FINANCIAL AND INSURANCE ACTIVITIES" if section == "K"
replace descr_section = "REAL ESTATE ACTIVITIES" if section == "L"
replace descr_section = "PROFESSIONAL, SCIENTIFIC AND TECHNICAL ACTIVITIES" if section == "M"
replace descr_section = "ADMNINISTRATIVE AND SUPPORT SERVICE ACTIVITIES" if section == "N"
replace descr_section = "PUBLIC ADMINISTRATION AND DEFENCE; COMPULSORY SOCIAL SECURITY" if section == "O"
replace descr_section = "EDUCATION" if section == "P"
replace descr_section = "HUMAN HEALTH AND SOCIAL WORK ACTIVITIES" if section == "Q"
replace descr_section = "ARTS, ENTERTAINMENT AND RECREATION" if section == "R"
replace descr_section = "OTHER SERVICE ACTIVITIES" if section == "S"
replace descr_section = "ACTIVITY OF HOUSEHOLDS AS EMPLOYERS; ACTIVITIES OF HOUSEHOLDS FOR OWN USE" if section == "T"
replace descr_section = "ACTIVITY OF EXTRATERRITORIAL ORGANISATIONS AND BODIES" if section == "U"

* GROUP 7: FIRM CHARACTERISTICS

gen capital_city = 0
cap replace capital_city = 1 if departamento =="FRANCISCO MORAZAN" // capital
cap replace capital_city = 1 if departamento =="CORTES" // industrial center
cap replace capital_city = . if departamento =="" // industrial center
gen region = departamento

gen incorporation_date = date(fecha_inicio_act, "DMY")
format incorporation_date %td

gen incorporation = year(incorporation_date)

replace incorporation = . if incorporation > 2019 & year > 2019
replace incorporation = . if incorporation > 2021 | incorporation < 1900 

gen firm_age = (year - incorporation) + 1 
replace firm_age = . if firm_age < 0

gen first_year = 0
replace first_year = 1 if firm_age <2 & firm_age != .

**
gen nb_employee = .
cap replace nb_employee = total_employees

gen total_assets = total_activo_sf 

* Generate intangible_assets & tangible assets
egen tangible_assets = rowtotal(propiedad_planta_eq activos_explotacion), missing

egen intangible_assets = rowtotal(activos_intangibles gastos_pag_anticipado), missing

gen total_asset_built = tangible_assets + intangible_assets - depreciacion_deterioro

sum total_assets total_asset_built total_pasivo_mas_patrimonio depreciacion_deterioro

/* Special regime data */
tab special_regime if regimenespecial==.
replace regimenespecial=0 if regimenespecial==.
replace regimenespecial=6 if regimenespecial==0
tab regimenespecial special_regime 

************* KEEP VARIABLES WE NEED *************
	* Create locals to keep variables
local group0 year country tax_ID entity  section descr_section tax_paid 
local group1 turnover exempt_income other_income total_income dividend_exempt dividend_income taxable_income codigoseccion clase
local group2 tot_cost *_inp deductible_cost depreciation cogs acc_depreciation
local group3 taxable_profit net_profit gross_profit
local group4 investment_taxbase capital_allowance loss_carryforward other_ded_taxbase net_tax_base gross_tax_base tot_deduc_taxbase net_tax_base_built
local group5 gross_tax_liability gross_tax_liability_as net_tax_liability net_tax_liability_as tot_deduc_taxliab cred_foreign_tax investment_taxliab other_cred_taxliab 
local group6 withholding partial_advanced_pay other_cred_tax_pay  ntl_noelse tot_noelse_taxliab special_taxliab trade_taxliab tax_to_remit     impuesto* *_base tax_form causa_impuesto
local group7 capital_city incorporation firm_age total_assets first_year nb_employee firm_age incorporation_date special_regime regimenespecial foreign_ownership   

	* Keep selected variables
keep  `group0' `group1' `group2' `group3' `group4' `group5' `group6' `group7'   total_operaciones_activo total_op_ingresos utilidad_ejercicio c518_tangibles c518_intangibles intangible_assets tangible_assets

	* Save

	* Final adjustments
sort tax_ID year, stable

	* Attempt to model STR:
	gen STR = 0	

	replace STR = 0.25 if year == 2017 | year == 2018 | year == 2019 | year == 2020 
	replace STR = (solidarity_tax_base*0.05+net_tax_base*0.25)/(net_tax_base) if solidarity_tax_base!=0 & (year == 2017 | year == 2018 | year == 2019 | year == 2020)

 
	replace STR = 0.3 if year == 2016 | year == 2015 | year == 2014
	replace STR = (solidarity_tax_base*0.05+net_tax_base*0.3)/(net_tax_base) if solidarity_tax_base!=0 & (year == 2016 | year == 2015 | year == 2014)
	
tempfile CIT
save `CIT'	

********* Merge Identifiers Orbis-Match **********

* Firm is scope of the GMT
use "$data/input/Honduras/GUO_ISRPJ_2014_2020_0305_WB.dta", clear

keep id year group guo_country_iso_code	n_total
rename id tax_ID
drop if year == .
duplicates drop tax_ID year, force

tempfile orbis
save `orbis'

use `CIT', clear
merge 1:1 tax_ID year using `orbis'


gen orbis_match = 0
replace orbis_match = 1 if _merge == 3
replace foreign_ownership = 1 if orbis_match == 1

**************************************************

/* SEZ variable */
gen sez=(special_regime!=3)

/* Save data */
sort tax_ID year, stable
export delimited using "$data/output/Honduras/HND_withvars.csv", replace 