*===============================================================================
* File name: 		SO2_JAM.do
* 
* Description:		This do-file creates the dataset SO2.dta. 
*
* Input:  					
*					$data/input/Jamaica/OECD_Req_Schedule A.xlsx
*					$data/input/Jamaica/OECD_Req_Schedule C.xlsx 
*
* Output:
*					$data/input/Jamaica/SO2.dta
*===============================================================================

cls
capture restore
set more off
cap log close
clear all

/* ----------------- */
/* Import SCH-A data */
/* ----------------- */

/* Load data */
import excel using "$data/input/Jamaica/OECD_Req_Schedule A.xlsx", clear first

gen year=year(FilingPeriod)
ren Anon_ID tax_ID

gen emoluments=Emol_Cash+Emol_Kind
gen other_payroll_taxes=NIS_Amt+NHT_Amt+EdTax_Amt+PAYE_Amt

keep year tax_ID emoluments other_payroll_taxes

tempfile temp
save `temp', replace

/* ----------------- */
/* Import SCH-C data */
/* ----------------- */

/* Load data */
import excel using "$data/input/Jamaica/OECD_Req_Schedule C.xlsx", clear first

ren ANON_ID tax_ID
gen year=year(ReturnFilingPeriod)
ren PensionAmount payroll_pension
gen other_payroll_deductions=ESOPAmount+ExpensesAmount+RetirementAmount

keep year tax_ID payroll_pension other_payroll_deductions

merge 1:1 tax_ID year using `temp'

drop if _merge==1
drop _merge

replace payroll_pension=0 if payroll_pension==.

foreach var of varlist payroll_pension other_payroll_deductions emoluments other_payroll_taxes {
	replace `var'=0 if `var'==. 
}

gen total_payroll_s02=emoluments+payroll_pension

/* Save data */
save "$data/input/Jamaica/SO2.dta", replace